@@ -5,7 +5,7 @@
  *
  * copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
+ * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
  *  This file is part of XCFA.
@@ -83,7 +83,8 @@ void libcombo_remove (void)
 	}
 	g_list_free (ListAlloc);
 	ListAlloc = NULL;
-	g_print ("\tRemove: %d\n", NbList);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\tRemove: %d\n", NbList);
 }
 // ALLOC COMBO
 // 
