@@ -5,7 +5,7 @@
  *
  * copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
+ * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
  *  This file is part of XCFA.
@@ -776,9 +776,11 @@ gboolean FileIs_jpg (gchar *namefile)
 gboolean FileIs_image( gchar *PathNameFile )
 {
 	GdkPixbuf *PixBuf = NULL;
-	if( NULL != ( PixBuf = gdk_pixbuf_new_from_file( PathNameFile, NULL ))) {
-		g_object_unref( PixBuf );
-		return( TRUE );
+	if( NULL != PathNameFile ) {
+		if( NULL != ( PixBuf = gdk_pixbuf_new_from_file( PathNameFile, NULL ))) {
+			g_object_unref( PixBuf );
+			return( TRUE );
+		}
 	}
 	return( FALSE );
 }
