@@ -5,7 +5,7 @@
  *
  * copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
+ * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
  *  This file is part of XCFA.
@@ -47,11 +47,19 @@
 #include <glib/gstdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <dirent.h>
+#include <stdlib.h>
 
 #include "lib.h"
 
 
 
+OPTIONS_COMMAND_LINE OptionsCommandLine = {
+	FALSE,		// gboolean	BoolVerboseMode
+	FALSE,		// gboolean	BoolVersionMode
+	FALSE		// gboolean	BoolHelpMode
+};
+
 
 
 // 
@@ -110,7 +118,8 @@ gchar *libutils_create_temporary_rep (gchar *SrcTmp, gchar *NewRepTmp)
 	if (NewRepTmp != NULL) {
 		Path = g_strdup_printf ("%s/%s", SrcTmp, NewRepTmp);
 		if (FALSE == libutils_test_dir_exist (Path)) {
-			g_print ("CREATE TEMPORARY REP:\n\t%s\n", Path);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("CREATE TEMPORARY REP:\n\t%s\n", Path);
 			g_mkdir_with_parents (Path, 0700);
 			// LineCommand = g_strdup_printf ("mkdir -p %s", Path);
 			// Dummy = system (LineCommand);
@@ -136,7 +145,8 @@ gchar *libutils_remove_temporary_rep (gchar *path_tmprep)
 				NULL
 				);
 		}
-		g_print ("REMOVE TEMPORARY REP:\n\t%s\n", path_tmprep);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("REMOVE TEMPORARY REP:\n\t%s\n", path_tmprep);
 		g_free (path_tmprep);
 		path_tmprep = NULL;
 	}
@@ -201,7 +211,7 @@ gchar *libutils_get_pathname_pixmaps (gchar *p_name_pixmap)
 {
 	gchar *LineCommand = NULL;
 	
-	LineCommand = g_strdup_printf ("%s/pixmaps/%s", PACKAGE_DATA_DIR, p_name_pixmap);
+	LineCommand = xdg_search_data_xdg( p_name_pixmap );
 	return (LineCommand);
 }
 // AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
@@ -211,8 +221,7 @@ void libutils_set_default_icone_to_win (GtkWidget *win)
 	gchar     *LineCommand = NULL;
 	GError    *error = NULL;
 
-	LineCommand = g_strdup_printf ("%s/pixmaps/xcfa.png", PACKAGE_DATA_DIR);
-	if (TRUE == libutils_test_file_exist (LineCommand)) {
+	if( NULL != (LineCommand = xdg_search_data_xdg( "xcfa.png" ))) {
 	 	gtk_window_set_icon_from_file (GTK_WINDOW(win), LineCommand, &error);
 	 	if (error) {
 	 		GDK_PIXBUF_ERROR;
@@ -389,7 +398,7 @@ gboolean libutils_test_write (gchar *path)
 }
 // INIT PIXBUF
 // 
-GdkPixbuf *libutils_init_pixbufs (char *NameFilePixbuf)
+GdkPixbuf *libutils_init_pixbufs (gchar *NameFilePixbuf)
 {
 	GdkPixbuf *NewPixbuf = NULL;
 	GError    *error = NULL;
@@ -497,6 +506,26 @@ gchar *libutils_get_name_without_ext( gchar *p_PathNameFile )
 
 	return( (gchar *)NewName );
 }
+// 
+// RETOURNE LE NOMBRE DE PROCESSUS ACTIF
+// http://geekiroxx.free.fr/weblog/index.php?article8/fonction-c-retournant-le-nombre-de-processus-actif-linux
+// 
+gint libutils_getNbProcess( void )
+{
+	struct dirent	*Read;
+	DIR		*Repo;
+	gint		pNbr = 0;
+	
+	Repo = opendir("/proc");
+	while( (Read = readdir(Repo)) )  {
+		if( atoi(Read->d_name) > 0 && atoi(Read->d_name) < 32768 )  {
+			// g_print( "[ %4d ] Read->d_name = %s\n", pNbr+1, Read->d_name );
+			pNbr ++;
+		}
+	}
+	closedir( Repo );
+	return( pNbr );
+}
 
 
 
