@@ -35,6 +35,14 @@
 #ifndef libH_h
 #define libH_h 1
 
+// /usr/include/gtk-2.0/gdk/gdkkeysyms.h
+typedef struct {
+	gboolean	BoolVerboseMode;
+	gboolean	BoolVersionMode;
+	gboolean	BoolHelpMode;
+} OPTIONS_COMMAND_LINE;
+
+extern OPTIONS_COMMAND_LINE OptionsCommandLine;
 
 // FILE_IS.C
 // 
@@ -75,7 +83,7 @@ size_t		libutils_get_size_file (gchar *PathName);
 void		libutils_add_datas_on_disk (gchar *data);
 gchar		*libutils_get_datas_on_disk (void);
 gboolean	libutils_test_write (gchar *path);
-GdkPixbuf	*libutils_init_pixbufs (char *NameFilePixbuf);
+GdkPixbuf	*libutils_init_pixbufs (gchar *NameFilePixbuf);
 gchar		*libutils_get_pathname_with_new_ext (gchar *PathName, gchar *NewExt);
 gboolean	libutils_test_file_with_new_ext_exist (gchar *PathName, gchar *NewExt);
 gint		*libutils_get_tab_selected_line (GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel);
@@ -83,6 +91,7 @@ gchar		*libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile );
 gchar		*libutils_get_name_without_ext( gchar *p_PathNameFile );
 gchar		*libutils_create_temporary_rep (gchar *SrcTmp, gchar *NewRepTmp);
 gchar		*libutils_remove_temporary_rep (gchar *path_tmprep);
+gint		libutils_getNbProcess( void );
 
 // COMBO.C
 // 
@@ -97,5 +106,12 @@ gchar		*utf8_convert_to_utf8 (const gchar *string);
 gchar		*utf8_removediacritics( const gchar *str, gssize len );
 gchar		*utf8_eperluette_name( gchar *p_name );
 
+// XDG.C
+// 
+void		xdg_print_list_config_path( void );
+void		xdg_print_list_data_path( void );
+gchar		*xdg_search_config_xdg( void );
+gchar		*xdg_search_data_xdg( gchar *NameFile );
+
 #endif
 
