@@ -185,7 +185,8 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 	
 	if (FALSE == tagswav_read_file (NameFile, &son)) {
 		tagswav_close_file (&son);
-		g_print ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", NameFile);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", NameFile);
 		return;
 	}
 	
@@ -202,10 +203,12 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 	default :
 		fclose (VarAlsa.pFile);
 		PRINT_FUNC_LF();
-		g_print("Seuls ces formats de bitrates : 8 16 24 et 32 sont pris en charge pour la lecture\n"
-			"Format de bitrate [ %d ] non prit en charge\n", 
-			son.FMT.BitsPerSample);
-		g_print("NO MUSIC :/\n");
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print("Seuls ces formats de bitrates : 8 16 24 et 32 sont pris en charge pour la lecture\n"
+				"Format de bitrate [ %d ] non prit en charge\n", 
+				son.FMT.BitsPerSample);
+			g_print("NO MUSIC :/\n");
+		}
 		return;
 	}
 	
@@ -234,7 +237,8 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 		VarAlsa.BoolThreadEnd    = FALSE;
 		VarAlsa.PercentSel       = 0.0;
 		PRINT("DEBUT THREAD ALSA");
-		g_print ("\t%s\n", NameFile);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("\t%s\n", NameFile);
 		pthread_create (&nmr_tid, NULL ,(void *)AlsaPlay_thread, (void *)NULL);
 		PRINT("DEBUT TIMEOUT ALSA");
 		VarAlsa.HandlerTimeout = gtk_timeout_add (100, AlsaPlay_timeout, 0);
@@ -243,8 +247,10 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 		fclose (VarAlsa.pFile);
 		AlsaAudio_close_device ();
 		PRINT_FUNC_LF();
-		g_print("Format de bitrate [ %d ] non prit en charge\n", son.FMT.BitsPerSample);
-		g_print("NO MUSIC :/\n");
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print("Format de bitrate [ %d ] non prit en charge\n", son.FMT.BitsPerSample);
+			g_print("NO MUSIC :/\n");
+		}
 	}
 }
 
