@@ -80,7 +80,6 @@ typedef struct {
 	GtkWidget		*Adr_notebook;				// 
 	GtkWidget		*Adr_entry_tag_titre_album;		// 
 	GtkWidget		*Adr_entry_tag_nom_artiste;		// 
-	GtkComboBox		*Adr_combobox_tag_genre_cd;		// 
 	GtkWidget		*Adr_spinbutton_tag_annee;		// 
 	GtkWidget		*Adr_entry_new_titre_cdaudio;		// 
 	GtkWidget		*Adr_entry_tag_titre_chanson;		// 
@@ -243,7 +242,6 @@ typedef struct {							// UN ENTETE POUR LE CD
 	gchar			 Str_Nice [ 10 ];			// Priorite systeme
 	gchar			 Str_Bitrate_Lame [ 10 ];		// Bitrate pour Lame
 	gchar			 Str_Bitrate_oggenc [ 10 ]; 		// Bitrate pour Oggenc
-	gchar			*StrMemoTagComment;			// Memorisation du commentaire
 } ENTETE_CD;
 
 extern ENTETE_CD EnteteCD;
@@ -275,14 +273,13 @@ void		cdaudio_affiche_glist_audio (void);
 void		cdaudio_update_glist (void);
 void		cdaudio_set_titre_chanson (void);
 CD_AUDIO	*cdaudio_get_line_selected (void);
-void		cdaudio_entry_stockage_cdaudio_changed (void);
 void		cdaudio_deallocate_glist_context (void);
 gboolean	cdaudio_get_bool_is_wav_extract_to_cue (void);
 void		cdaudio_put_label_titre (gchar *Messag);
 void		cdaudio_put_label_duree (gchar *Messag);
-gchar		*cdaudio_get_TitleCD (void);
 void		cdaudio_from_popup (TYPE_SET_FROM_POPUP_CD TypeSetFromPopup, CD_AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
 void		cd_audio_bool_access_discid( gboolean p_bool_access );
+CD_AUDIO	*cdaudio_get_line_selected_for_extract( void );
 
 /*
 *---------------------------------------------------------------------------
@@ -298,6 +295,7 @@ void		cdexpander_set_entry_tag_commentaire (void);
 void		cdexpander_set_spinbutton_tag_piste (void);
 void		cdexpander_set_entry_tag_titre_fichier_m3u (void);
 void		cdexpander_set_sensitive_notebook (void);
+void		cd_expander_set_genre( gint p_num, gchar *p_name );
 
 /*
 *---------------------------------------------------------------------------
