@@ -24,8 +24,11 @@
  *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* Xcfa essayes de reprendre quelques fonctionnalites interessantes de 'rubyripper'
- *	http://code.google.com/p/rubyripper/
+/*
+ * Extraction avec cdparanoia en mode expert.
+ * XCFA essayes de reprendre quelques fonctionnalités interessantes de 'rubyripper' [ http://code.google.com/p/rubyripper/ ]
+ * Deux extractions de la même piste sont faites puis comparées.
+ * Les segments non valides seront relus jusqu'à quatre fois si nécessaire puis validés si possible.
  *
 	--------------------------------------------------------------------
 	VERIF FICHIER cdparanoia mode expert
@@ -591,7 +594,7 @@ void cdaudioextract_set_list_to_vte (gchar *p_text)
 }
 // 
 // 
-void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2, gchar *PathNameDest, size_t LenFile)
+void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2, gchar *PathNameDest, size_t LenFile)
 {
 	FILE		*fp1 = NULL;
 	FILE		*fp2 = NULL;
@@ -612,8 +615,8 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2
 	gint		 NbrPass;
 		
 	// Ouverture en lecture des 2 fichiers
-	fp1 = fopen (FileExtarct_1, "r");
-	fp2 = fopen (FileExtarct_2, "r");
+	fp1 = fopen (FileExtract_1, "r");
+	fp2 = fopen (FileExtract_2, "r");
 	// Ouverture de la destination
 	fp3 = fopen (PathNameDest, "w");
 	
@@ -677,8 +680,7 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2
 			// 
 						
 			// Extraction segment 'Elem' PASS 1/2
-			Name1 = cdaudioextract_new_name (FileExtarct_1, "1.wav");
-		g_print("Name1 = %s\n", Name1);
+			Name1 = cdaudioextract_new_name (FileExtract_1, "1.wav");
 			filelc_get_command_line_extract_elem (Elem, EnteteCD.NameCD_Device, Name1);
 			conv_exec_extract (FALSE, CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT, "CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT");
 			
@@ -687,8 +689,7 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2
 			cdaudioextract_set_list_to_vte (Str);
 			g_free (Str);
 			Str = NULL;
-			Name2 = cdaudioextract_new_name (FileExtarct_2, "2.wav");
-		g_print("Name2 = %s\n", Name2);
+			Name2 = cdaudioextract_new_name (FileExtract_2, "2.wav");
 
 			filelc_get_command_line_extract_elem (Elem, EnteteCD.NameCD_Device, Name2);
 			conv_exec_extract (FALSE, CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT, "CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT");
@@ -742,9 +743,11 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 
 			if (FALSE == conv.bool_stop && Audio->Etat_Wav == ETAT_CONV_CD_WAITING) {
 
-				g_print ("\n");
-				g_print ("SOURCE CD<%s>\n", Audio->Str_Track);
-				g_print ("DEST   WAV<%s>\n", Audio->PathName_Dest_Wav);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					g_print ("\n");
+					g_print ("SOURCE CD<%s>\n", Audio->Str_Track);
+					g_print ("DEST   WAV<%s>\n", Audio->PathName_Dest_Wav);
+				}
 				
 				switch (Config.ExtractCdWith) {
 				case EXTRACT_WITH_CDPARANOIA :
@@ -1083,6 +1086,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
 				filelc_get_command_line_remove ();
 	PRINT("DEBUG FOR @DZEF");
+if( TRUE == OptionsCommandLine.BoolVerboseMode )
 	g_print("\t%s = %s\n\n", VarCdExtract.NameFileFormatUnique, libutils_test_file_exist (VarCdExtract.NameFileFormatUnique) ? "EXIST" : "NOT FOUND");
 	
 				conv.Bool_MAJ_select = TRUE;
@@ -1097,9 +1101,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 			
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   FLAC<%s>\n", Audio->PathName_Dest_Flac);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   FLAC<%s>\n", Audio->PathName_Dest_Flac);
+			}
 			
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
@@ -1123,10 +1129,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   APE <%s>\n", Audio->PathName_Dest_Ape);
-			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   APE <%s>\n", Audio->PathName_Dest_Ape);
+			}
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
 			// logs_write_datas (" -> ");
@@ -1152,9 +1159,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			gchar   *path = NULL;
 			gchar   *ptr = NULL;
 				
-			g_print ("\n");
-			g_print ("SOURCE WAV     <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   WAVPACK <%s>\n", Audio->PathName_Dest_WavPack);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV     <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   WAVPACK <%s>\n", Audio->PathName_Dest_WavPack);
+			}
 			
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
@@ -1195,10 +1204,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   OGG <%s>\n", Audio->PathName_Dest_Ogg);
-			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   OGG <%s>\n", Audio->PathName_Dest_Ogg);
+			}
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
 			// logs_write_datas (" -> ");
@@ -1221,10 +1231,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   M4A <%s>\n", Audio->PathName_Dest_M4a);
-			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   M4A <%s>\n", Audio->PathName_Dest_M4a);
+			}
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
 			// logs_write_datas (" -> ");
@@ -1247,10 +1258,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   AAC <%s>\n", Audio->PathName_Dest_Aac);
-			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   AAC <%s>\n", Audio->PathName_Dest_Aac);
+			}
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
 			// logs_write_datas (" -> ");
@@ -1275,10 +1287,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   MPC <%s>\n", Audio->PathName_Dest_Mpc);
-			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   MPC <%s>\n", Audio->PathName_Dest_Mpc);
+			}
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
 			// logs_write_datas (" -> ");
@@ -1301,10 +1314,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
-			g_print ("\n");
-			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
-			g_print ("DEST   MP3 <%s>\n", Audio->PathName_Dest_Mp3);
-			
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print ("\n");
+				g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
+				g_print ("DEST   MP3 <%s>\n", Audio->PathName_Dest_Mp3);
+			}
 			// logs_write_datas ("\t");
 			// logs_write_datas (Audio->PathName_Dest_Wav);
 			// logs_write_datas (" -> ");
@@ -1526,7 +1540,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Flac) {
 					if (Audio->Bool_Delette_Flac) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Flac);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Flac);
 						g_unlink (Audio->PathName_Dest_Flac);
 					}
 					g_free (Audio->PathName_Dest_Flac);
@@ -1535,7 +1550,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Wav) {
 					if (Audio->Bool_Delette_Wav) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Wav);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Wav);
 						g_unlink (Audio->PathName_Dest_Wav);
 					}
 					g_free (Audio->PathName_Dest_Wav);
@@ -1544,7 +1560,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Mp3) {
 					if (Audio->Bool_Delette_Mp3) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Mp3);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Mp3);
 						g_unlink (Audio->PathName_Dest_Mp3);
 					}
 					g_free (Audio->PathName_Dest_Mp3);
@@ -1553,7 +1570,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Ogg) {
 					if (Audio->Bool_Delette_Ogg) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Ogg);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Ogg);
 						g_unlink (Audio->PathName_Dest_Ogg);
 					}
 					g_free (Audio->PathName_Dest_Ogg);
@@ -1562,7 +1580,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_M4a) {
 					if (Audio->Bool_Delette_M4a) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_M4a);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_M4a);
 						g_unlink (Audio->PathName_Dest_M4a);
 					}
 					g_free (Audio->PathName_Dest_M4a);
@@ -1571,7 +1590,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Aac) {
 					if (Audio->Bool_Delette_Aac) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Aac);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Aac);
 						g_unlink (Audio->PathName_Dest_Aac);
 					}
 					g_free (Audio->PathName_Dest_Aac);
@@ -1580,7 +1600,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Mpc) {
 					if (Audio->Bool_Delette_Mpc) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Mpc);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Mpc);
 						g_unlink (Audio->PathName_Dest_Mpc);
 					}
 					g_free (Audio->PathName_Dest_Mpc);
@@ -1589,7 +1610,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_Ape) {
 					if (Audio->Bool_Delette_Ape) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Ape);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_Ape);
 						g_unlink (Audio->PathName_Dest_Ape);
 					}
 					g_free (Audio->PathName_Dest_Ape);
@@ -1598,7 +1620,8 @@ static gint cdaudioextract_timeout (gpointer data)
 
 				if (Audio->PathName_Dest_WavPack) {
 					if (Audio->Bool_Delette_WavPack) {
-						g_print ("g_unlink (%s)\n", Audio->PathName_Dest_WavPack);
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("g_unlink (%s)\n", Audio->PathName_Dest_WavPack);
 						g_unlink (Audio->PathName_Dest_WavPack);
 					}
 					g_free (Audio->PathName_Dest_WavPack);
@@ -1617,7 +1640,8 @@ static gint cdaudioextract_timeout (gpointer data)
 		}
 		
 		if (VarCdExtract.ChoiceFileCue > 0) {
-			g_print ("g_unlink (%s)\n", VarCdExtract.PathName_SrcWavSox);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("g_unlink (%s)\n", VarCdExtract.PathName_SrcWavSox);
 			g_unlink (VarCdExtract.PathName_SrcWavSox);
 		}
 		
