@@ -58,6 +58,7 @@
 #include "statusbar.h"
 #include "prg_init.h"
 #include "cd_curl.h"
+#include "options.h"
 
 
 
@@ -106,7 +107,7 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 				cdaudio_put_label_duree (EnteteCD.StrDureeCd);
 				cdaudio_put_label_titre (EnteteCD.TitleCD);
 
-				cdaudio_entry_stockage_cdaudio_changed ();
+				OptionsCd_set_entry_and_label();
 				
 				/* TO DEBUG : A VERIFIER DES QUE CONNECTION WEB EST OK
 
@@ -182,7 +183,6 @@ void cdaudiotoc_reffresh_list_cd (void)
 		  	"");
 		return;
 	}
-	// if( FALSE == libutils_find_file( "cd-discid" )) {
 	if( FALSE == PrgInit.bool_cd_discid ) {
 		wininfo_create (
 			_("cd-discid NOT FOUND"),
@@ -205,15 +205,6 @@ void cdaudiotoc_reffresh_list_cd (void)
 			return;
 		}
 	}
-
-	// 
-	// SI ACCES EST FALSE, LES TRACK SERONT RECUPEREES
-	// 
-	// if( FALSE == CdCddb_test_access_web()) {
-	// 	PRINT_FUNC_LF();
-	// 	g_print( "\tAccess WEB is FALSE !\n" );
-	// 	return;
-	// }
 	
 	WindScan_open ("Scan CD", WINDSCAN_PULSE);
 	WindScan_show_cancel( FALSE );
