@@ -228,10 +228,6 @@ void CdCurl_init_entete_cd (void)
 		g_free( EnteteCD.Message );
 		EnteteCD.Message = NULL;
 	}
-	if( NULL != EnteteCD.StrMemoTagComment ) {
-		g_free( EnteteCD.StrMemoTagComment );
-		EnteteCD.StrMemoTagComment = NULL;
-	}
 }
 //
 //
@@ -318,13 +314,14 @@ gchar *CdCurl_get_title_cd( void )
 {
 	return( view.TitleCD );
 }
-//
-//
+// 
+// 
 void CdCurl_set_list_discid( void )
 {
 	if( NULL != VarSector.ListDiscId ) {
 		GList		*List = NULL;
 		VAR_LIST_POPUP	*PtrVarList = NULL;
+		gint		NbrOptions = 0;
 
 		libcombo_remove_options( GTK_COMBO_BOX(var_cd.Adr_combobox_discid_cd));
 		gtk_combo_box_set_active( GTK_COMBO_BOX(var_cd.Adr_combobox_discid_cd), 0 );
@@ -333,11 +330,17 @@ void CdCurl_set_list_discid( void )
 		while ( List ) {
 			if( NULL != ( PtrVarList = (VAR_LIST_POPUP *)List->data )) {
 				gtk_combo_box_append_text( GTK_COMBO_BOX(var_cd.Adr_combobox_discid_cd), PtrVarList->NameGenre );
+				NbrOptions ++;
 			}
 			List = g_list_next( List );
 		}
 		gtk_combo_box_set_active( GTK_COMBO_BOX(var_cd.Adr_combobox_discid_cd), VarSector.NumForceFromPopUp > -1 ? VarSector.NumForceFromPopUp : 0 );
-		gtk_widget_show( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
+		// gtk_widget_show( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
+		if( NbrOptions > 1 )
+			gtk_widget_show( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
+		else	gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print( "NbrOptions = %d [ %s ]\n", NbrOptions,  NbrOptions > 1 ? "gtk_widget_show" : "gtk_widget_hide" );
 		return;
 	}
 	gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
@@ -366,6 +369,9 @@ void CdCurl_set_call( gint p_num_from_popup, gchar *p_CallStrDiscID, gchar *p_Ca
 			if( NULL != ( PtrVarList = (VAR_LIST_POPUP *)List->data )) {
 				if( NULL != PtrVarList->StrCdDiscId ) {
 					VarSector.CallStrDiscID = g_strdup( PtrVarList->StrCdDiscId );
+					// DEBUG: TO SEE OTHER DsicId
+					// VarSector.CallStrDiscID = g_strdup( "c60a1a0f" ); 
+					
 					VarSector.CallStrGenre = g_strdup( PtrVarList->NameGenre );
 				}
 			}
@@ -431,6 +437,7 @@ void CdCurl_print_glist( void )
 	VAR_LIST_POPUP	*PtrVarList = NULL;
 	
 	PRINT_FUNC_LF();
+	if( FALSE == OptionsCommandLine.BoolVerboseMode ) return;
 	List = g_list_first( VarSector.ListDiscId );
 	while( List ) {
 		if( NULL != ( PtrVarList = (VAR_LIST_POPUP *)List->data )) {
@@ -526,15 +533,17 @@ gchar *CdCurl_disc_db_make_request( gchar *p_Cmd )
 			curl_easy_setopt( curl_handle, CURLOPT_PROXY, StrNamePort );
 			g_free( StrNamePort );
 			StrNamePort = NULL;
-			g_print( "\n" );
-			g_print( "!-------------------------------------------------\n" );
-			g_print( "! AT THE REQUEST OF @Gounlaf:\n");
-			g_print( "!    Gestion du proxy\n" );
-			g_print( "!    Management PROXY\n" );
-			g_print( "!-------------------------------------------------\n" );
-			g_print( "!\tConfig.entry_proxy_server = %s\n", Config.entry_proxy_server ); 
-			g_print( "!\tConfig.entry_proxy_port   = %s\n", Config.entry_proxy_port ); 
-			g_print( "!-------------------------------------------------\n\n" );
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				g_print( "\n" );
+				g_print( "!-------------------------------------------------\n" );
+				g_print( "! AT THE REQUEST OF @Gounlaf:\n");
+				g_print( "!    Gestion du proxy\n" );
+				g_print( "!    Management PROXY\n" );
+				g_print( "!-------------------------------------------------\n" );
+				g_print( "!\tConfig.entry_proxy_server = %s\n", Config.entry_proxy_server ); 
+				g_print( "!\tConfig.entry_proxy_port   = %s\n", Config.entry_proxy_port ); 
+				g_print( "!-------------------------------------------------\n\n" );
+			}
 		}
 		curl_easy_setopt( curl_handle, CURLOPT_URL, p_Cmd );
 		strcpy( user_agent, PACKAGE_STRING );
@@ -563,6 +572,11 @@ gchar *CdCurl_disc_db_make_request( gchar *p_Cmd )
 	}
 	curl_global_cleanup();
 	
+	if( NULL != DatasBuffer && NULL != strstr( DatasBuffer, "500 Internal Server Error" )) {
+		g_free( DatasBuffer );
+		DatasBuffer = NULL;
+		PRINT("DatasBuffer -> 500 Internal Server Error" );
+	}
 	return( DatasBuffer );
 }
 // 
@@ -579,8 +593,10 @@ DO_CURL_QUERY CdCurl_discdb_do_query( void )
 	gint		CodeRetData;
 	gboolean	BoolCodeRet = DO_CURL_QUERY_TRUE;
 	
-	g_print( "\n" );
-	g_print( "GSTR_QUERY = %s\n", Gstr->str );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print( "\n" );
+		g_print( "GSTR_QUERY = %s\n", Gstr->str );
+	}
 	g_string_free( Gstr, TRUE );
 	Gstr = NULL;
 	
@@ -590,16 +606,18 @@ DO_CURL_QUERY CdCurl_discdb_do_query( void )
 		return( DO_CURL_QUERY_FALSE );
 	}
 	Larrbuf = g_strsplit( DatasBuffer, "\n", 0 );
-	g_print( "\nQUERY\n" );
-	for( Cpt = 0; Larrbuf[ Cpt ]; Cpt ++ ) {
-		g_print( "%s\n", Larrbuf[ Cpt ] );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print( "\nQUERY\n" );
+		for( Cpt = 0; Larrbuf[ Cpt ]; Cpt ++ ) {
+			g_print( "%s\n", Larrbuf[ Cpt ] );
+		}
+		g_print( "\n" );
 	}
-	g_print( "\n" );
-	
 	// TEST DU CODE DE RETOUR
 	// ----------------------
 	CodeRetData = atoi( DatasBuffer );
-	g_print( "CodeRetData = %d\n", CodeRetData );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print( "CodeRetData = %d\n", CodeRetData );
 	switch( CodeRetData ) {
 	case 200 :
 		// 200 blues dc0c720f Various / L'âme du blues (CD1)
@@ -688,8 +706,10 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 	if( DO_CURL_QUERY_TRUE == p_DoCurlQuery ) {
 		Gstr        = CdCurl_make_line_request_for_read( CdCurl_get_str_genre(), CdCurl_get_str_discid() );
 		DatasBuffer = CdCurl_disc_db_make_request( Gstr->str );
-		g_print( "\n" );
-		g_print( "GSTR_READ = %s\n", Gstr->str );
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print( "\n" );
+			g_print( "GSTR_READ = %s\n", Gstr->str );
+		}
 		g_string_free( Gstr, TRUE );
 		Gstr = NULL;
 	}	
@@ -742,7 +762,7 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			VarSector.ListSector[ Track ].Title = g_strdup( Audio->NameSong	);
 		
 			Audio->tags = ( TAGS * )tags_alloc( TRUE );
-			Audio->tags->Album		= g_strdup ("Track");
+			Audio->tags->Album		= g_strdup ("Album");
 			Audio->tags->Artist		= g_strdup ("Artist");
 			Audio->tags->Title		= g_strdup_printf ("Track_%02d", Track +1);
 			Audio->tags->Number		= g_strdup_printf ("%d", Track +1);
@@ -751,8 +771,10 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			Audio->tags->IntGenre		= 123;
 			Audio->tags->Year		= g_strdup ("1962");
 			Audio->tags->IntYear		= 1962;
-			Audio->tags->Comment		= g_strdup ("By Xcfa");
-			Audio->tags->Description	= g_strdup ("By Xcfa");
+			// Audio->tags->Comment		= g_strdup ("By Xcfa");
+			// Audio->tags->Description	= g_strdup ("By Xcfa");
+			Audio->tags->Comment		= g_strdup( Config.StringCommentCD );
+			Audio->tags->Description	= g_strdup( Config.StringCommentCD );
 
 			EnteteCD.GList_Audio_cd = g_list_append( EnteteCD.GList_Audio_cd, (CD_AUDIO *)Audio );
 			
@@ -769,13 +791,18 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			view.TitleCD = g_strdup( "Track" );
 		}
 		CdCurl_set_datas_buffer( gstr_buffer_title, gstr_buffer_title_time, gstr_buffer_artist_title_time );
+		
 		return;
 	}
 	
 	Larrbuf = g_strsplit( DatasBuffer, "\n", 0 );
-	g_print( "\nREAD\n" );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print( "\nREAD\n" );
+	
 	for( Cpt = 0; Larrbuf[ Cpt ]; Cpt ++ ) {
-		g_print( "%s\n", Larrbuf[ Cpt ] );
+		
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print( "%s\n", Larrbuf[ Cpt ] );
 		
 		if( ! strncasecmp( Larrbuf[ Cpt ], "DTITLE", 6 )) {
 
@@ -864,7 +891,25 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			VarSector.ListSector[ Track ].Title = g_strdup( Audio->NameSong	);
 		
 			Audio->tags = ( TAGS * )tags_alloc( TRUE );
-			Audio->tags->Album		= g_strdup( EnteteCD.TitleCD );
+		
+			// JEROME JOLIMONT
+			// 
+			// Une fois la recherche effectuée, il y a dans le champ "Album", la chaîne de
+			// caractères correspondant à la concaténation des chaînes "Artist", " - " et
+			// "Album". Ca ne me paraît pas normal. C'est voulu ?
+			// 
+			// SOLVED:
+			// Audio->tags->Album		= g_strdup( EnteteCD.TitleCD );
+			// 
+			if( NULL != ( PtrNameTrack = strchr( EnteteCD.TitleCD, '-' ))) {
+				PtrNameTrack ++;
+				while( ' ' == *PtrNameTrack ) PtrNameTrack++;
+				Audio->tags->Album = g_strdup( PtrNameTrack );
+			}
+			else {
+				Audio->tags->Album		= g_strdup( EnteteCD.TitleCD );
+			}
+			
 			Audio->tags->Artist		= g_strdup( EnteteCD.Artiste );
 			Audio->tags->Title		= g_strdup( Audio->NameSong	 );
 			Audio->tags->Year		= g_strdup( EnteteCD.StrYear );
@@ -873,8 +918,10 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			Audio->tags->Genre		= g_strdup( EnteteCD.StrGenre );
 			Audio->tags->Number		= g_strdup_printf ("%d", Track +1);
 			Audio->tags->IntNumber		= Track +1;
-			Audio->tags->Comment		= g_strdup ("By Xcfa");
-			Audio->tags->Description	= g_strdup( "By Xcfa" );
+			// Audio->tags->Comment		= g_strdup ("By Xcfa");
+			// Audio->tags->Description	= g_strdup( "By Xcfa" );
+			Audio->tags->Comment		= g_strdup( Config.StringCommentCD );
+			Audio->tags->Description	= g_strdup( Config.StringCommentCD );
 
 			EnteteCD.GList_Audio_cd = g_list_append( EnteteCD.GList_Audio_cd, (CD_AUDIO *)Audio );
 			
@@ -894,7 +941,8 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 		}
 	}
 	CdCurl_set_datas_buffer( gstr_buffer_title, gstr_buffer_title_time, gstr_buffer_artist_title_time );
-	g_print( "\n" );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print( "\n" );
 	g_strfreev( Larrbuf );
 	g_free( DatasBuffer );
 	DatasBuffer = NULL;
@@ -975,8 +1023,8 @@ void CdCurl_cdparanoia_get_sectors ( gchar *buffer )
 void CdCurl_set_datas_for_cdcue( void )
 {
 	gint	Track;
-	gint		TempDiv;
-	gint		TempMod;
+	gint	TempDiv;
+	gint	TempMod;
 	
 	cdcue_alloc_base_ioctl( VarSector.TotalTracks );
 	for( Track = 0; Track < VarSector.TotalTracks; Track++ ) {
@@ -1013,15 +1061,40 @@ void CdCurl_set_datas_for_cdcue( void )
 	
 	cdcue_make_cue();
 
+	/*
+	-- void CdCurl_set_datas_for_cdcue_two( void )
+	
 	BaseIoctl.Performer = g_strdup( EnteteCD . TitleCD );
 	BaseIoctl.Title     = g_strdup( EnteteCD . TitleCD );
 	BaseIoctl.File      = g_strdup_printf ("%s.wav", EnteteCD . TitleCD);
+	
+	g_print( "BaseIoctl.Performer = %s\n", BaseIoctl.Performer );
+	g_print( "BaseIoctl.Title     = %s\n", BaseIoctl.Title );
+	g_print( "BaseIoctl.File      = %s\n", BaseIoctl.File );
 
 	for( Track = 0; Track < VarSector.TotalTracks; Track++ ) {
 		BaseIoctl.Cue [ Track ].Performer = g_strdup( EnteteCD . TitleCD );
 		BaseIoctl.Cue [ Track ].Title     = g_strdup( VarSector.ListSector[ Track ].Title );
 	}
 
+	cdcue_print_base_ioctl();
+	*/
+}
+//
+//
+void CdCurl_set_datas_for_cdcue_two( void )
+{
+	gint	Track;
+	
+	BaseIoctl.Performer = g_strdup( EnteteCD . TitleCD );
+	BaseIoctl.Title     = g_strdup( EnteteCD . TitleCD );
+	BaseIoctl.File      = g_strdup_printf ("%s.wav", EnteteCD . TitleCD);
+	
+	for( Track = 0; Track < VarSector.TotalTracks; Track++ ) {
+		BaseIoctl.Cue [ Track ].Performer = g_strdup( EnteteCD . TitleCD );
+		BaseIoctl.Cue [ Track ].Title     = g_strdup( VarSector.ListSector[ Track ].Title );
+	}
+	
 	cdcue_print_base_ioctl();
 }
 //
@@ -1062,22 +1135,26 @@ gboolean CdCurl_get_info_cd( void )
 		VarSector.LenDisc      = atoi( Larrbuf[ Cpt -1 ] );
 		g_strfreev( Larrbuf );
 		if( NULL != ( Ptr = strchr( VarSector.GStrCdDiscID->str, '\n' ))) *Ptr = '\0';
-		g_print( "StrDiscID    = %s\n", VarSector.StrDiscID );
-		g_print( "GStrCdDiscID = %s\n", VarSector.GStrCdDiscID->str );
-		g_print( "LenDisc      = %d: ", VarSector.LenDisc );
-		g_print( "\n" );
-		
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print( "StrDiscID    = %s\n", VarSector.StrDiscID );
+			g_print( "GStrCdDiscID = %s\n", VarSector.GStrCdDiscID->str );
+			g_print( "LenDisc      = %d: ", VarSector.LenDisc );
+			g_print( "\n" );
+		}
 		// GET REAL TRACKS AND GET REAL SECTORS FROM CDPARANOIA
 		gstr = GetInfo_cdparanoia (EnteteCD.NameCD_Device);
-		g_print("gstr->str=\n%s", gstr->str);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print("gstr->str=\n%s", gstr->str);
 		if( ( VarSector.TotalTracks = CdCurl_cdparanoia_get_total_tracks( gstr->str ) ) > -1 ) {
 			CdCurl_cdparanoia_get_sectors( gstr->str );
 		}
 		g_string_free (gstr, TRUE);
 		gstr = NULL;
-		g_print( "total_tracks with cdparanoia = %d\n", VarSector.TotalTracks );
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print( "total_tracks with cdparanoia = %d\n", VarSector.TotalTracks );
 		
 		if( VarSector.TotalTracks > -1 ) {
+			
 			// SET DATAS FOR CD_CUE
 			CdCurl_set_datas_for_cdcue();
 		
@@ -1094,13 +1171,17 @@ gboolean CdCurl_get_info_cd( void )
 				}
 				break;
 			}
+			
+			// SET DATAS FOR CD_CUE
+			CdCurl_set_datas_for_cdcue_two();
 		}
 		else {
 			CdCurl_remove_struct();
 			BoolRet = FALSE;
 			EnteteCD.Message = g_strdup( _("No Audio CD") );
 		}
-		g_print( "\n" );
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print( "\n" );
 	}
 	return( BoolRet );
 }
