@@ -49,6 +49,7 @@
 #include "cd_audio.h"
 #include "configuser.h"
 #include "parse.h"
+#include "popup.h"
 
 
 
@@ -164,9 +165,9 @@ void cdexpander_set_new_genre (void)
 {
 	CD_AUDIO            *Audio = NULL;
 
-	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_combobox_tag_genre_cd) {
+	if (NULL != (Audio = cdaudio_get_line_selected ()) ) {
 		VarCdExpander.BoolChangedOk = FALSE;
-		gtk_combo_box_set_active (GTK_COMBO_BOX (var_cd.Adr_combobox_tag_genre_cd), tags_get_elements_combobox (Audio->tags->IntGenre));
+		gtk_entry_set_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre")), tags_get_genre_by_name( Audio->tags->IntGenre ));
 		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
@@ -191,7 +192,7 @@ void cdexpander_set_entry_tag_commentaire (void)
 	}
 	else {
 		VarCdExpander.BoolChangedOk = FALSE;
-		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire), "");
+		gtk_entry_set_text( GTK_ENTRY(var_cd.Adr_entry_tag_commentaire), Config.StringCommentCD );
 		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
@@ -307,78 +308,26 @@ void on_entry_tag_nom_artiste_changed (GtkEditable *editable, gpointer user_data
 }
 // 
 // 
-void on_button_copy_commentaire_clicked (GtkButton *button, gpointer user_data)
-{
-	gchar        *ptr_template = NULL;
-	
-	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire));
-	if (NULL != EnteteCD.StrMemoTagComment) {
-		g_free (EnteteCD.StrMemoTagComment);
-		EnteteCD.StrMemoTagComment = NULL;
-	}
-	EnteteCD.StrMemoTagComment = g_strdup (ptr_template);
-	
-	cdaudio_set_flag_buttons ();
-}
-// 
-// 
-void on_button_paste_comment_clicked (GtkButton *button, gpointer user_data)
-{
-	gint          Num_cell = 0;
-	gboolean      valid;
-	GtkTreeIter   iter;
-	GList        *List = NULL;
-	CD_AUDIO     *Audio = NULL;
-	
-	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
-	while (valid) {
-		List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-		if (NULL != (Audio = (CD_AUDIO *)List->data)) {
-			g_free (Audio->tags->Comment);
-			Audio->tags->Comment = NULL;
-			Audio->tags->Comment = g_strdup (EnteteCD.StrMemoTagComment);
-		}
-		valid = gtk_tree_model_iter_next (var_cd.Adr_Tree_Model, &iter);
-		Num_cell ++;
-	}
-	gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire), EnteteCD.StrMemoTagComment);
-	cdaudio_set_titre_chanson ();
-}
-// 
-// 
 void on_entry_tag_commentaire_changed (GtkEditable *editable, gpointer user_data)
 {
-	gint          Num_cell = 0;
-	gboolean      valid;
-	GtkTreeIter   iter;
-	GList        *List = NULL;
-	gchar        *ptr_template = NULL;
+	gchar        *ptr_template = NULL; 
 	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_commentaire) return;
-	if (FALSE == VarCdExpander.BoolChangedOk) return;
+	
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire));
-		
-	if (TRUE == EnteteCD.BoolMultiArtiste) {
-		if (NULL != (Audio = cdaudio_get_line_selected ())) {
-			g_free (Audio->tags->Comment);
-			Audio->tags->Comment = NULL;
-			Audio->tags->Comment = g_strdup (ptr_template);
-		}
+	if( NULL != Config.StringCommentCD ) {
+		g_free( Config.StringCommentCD );
+		Config.StringCommentCD = NULL;
 	}
-	else {
-		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
-		while (valid) {
-			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
-				g_free (Audio->tags->Comment);
-				Audio->tags->Comment = NULL;
-				Audio->tags->Comment = g_strdup (ptr_template);
-			}
-			valid = gtk_tree_model_iter_next (var_cd.Adr_Tree_Model, &iter);
-			Num_cell ++;
-		}
+	Config.StringCommentCD = g_strdup( ptr_template );
+	
+	if( NULL != ( Audio = cdaudio_get_line_selected())) {
+		g_free( Audio->tags->Comment );
+		Audio->tags->Comment = NULL;
+		Audio->tags->Comment = g_strdup( Config.StringCommentCD );
 	}
+	
 	cdaudio_set_titre_chanson ();
 }
 // 
@@ -460,49 +409,88 @@ void on_entry_tag_titre_fichier_m3u_changed (GtkEditable *editable, gpointer use
 }
 // 
 // 
-void on_combobox_tag_genre_cd_changed (GtkComboBox *combobox, gpointer user_data)
+void cd_expander_set_genre( gint p_num, gchar *p_name )
 {
 	gint          Num_cell = 0;
 	gboolean      valid;
 	GtkTreeIter   iter;
 	GList        *List = NULL;
-	gchar        *ptr_template = NULL;
 	CD_AUDIO     *Audio = NULL;
-	gint          IntGenre;
 	
-	if (NULL == var_cd.Adr_combobox_tag_genre_cd) return;
-	
-	IntGenre = gtk_combo_box_get_active (var_cd.Adr_combobox_tag_genre_cd);
-	ptr_template = (gchar *)gtk_combo_box_get_active_text (var_cd.Adr_combobox_tag_genre_cd);
-
-	if (TRUE == EnteteCD.BoolMultiArtiste) {
-		if (NULL != (Audio = cdaudio_get_line_selected ())) {
+	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
+	while (valid) {
+		List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
+		if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 			g_free (Audio->tags->Genre);
 			Audio->tags->Genre = NULL;
-			Audio->tags->Genre = g_strdup (ptr_template);
-			Audio->tags->IntGenre = tags_get_num_combobox (IntGenre);
-		}
-	}
-	else {
-		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
-		while (valid) {
-			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
-				g_free (Audio->tags->Genre);
-				Audio->tags->Genre = NULL;
-				Audio->tags->Genre = g_strdup (ptr_template);
-				Audio->tags->IntGenre = tags_get_num_combobox (IntGenre);
-			}
-			valid = gtk_tree_model_iter_next (var_cd.Adr_Tree_Model, &iter);
-			Num_cell ++;
+			Audio->tags->Genre = g_strdup( p_name );
+			Audio->tags->IntGenre = p_num;
 		}
+		valid = gtk_tree_model_iter_next (var_cd.Adr_Tree_Model, &iter);
+		Num_cell ++;
 	}
 	cdaudio_set_titre_chanson ();
 }
+void on_entry_tag_genre_changed( GtkEditable *editable, gpointer user_data )
+{
+	gchar	*PtrEntry = NULL;
+	gint	NumEntry = -1;
+	
+	if( FALSE == CdPopupGenre.BoolFromPopup ) {
+		PRINT_FUNC_LF();
+		PtrEntry = (gchar *)gtk_entry_get_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre")));
+		NumEntry = tags_get_genre_by_value( PtrEntry );
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print( "\tPtrEntry = %s\n", PtrEntry );
+			g_print( "\tNumEntry = %d\n", NumEntry);
+		}
+		cd_expander_set_genre( NumEntry, PtrEntry );
+	}
+}
+// 
+// Completion de la saisie clavier
+// http://coding.debuntu.org/c-gtk-text-completion-gtkentry-gtkentrycompletion
+// 
+#define _CONTACT_NAME_	0
+// typedef struct {
+// 	gint   num;
+// 	gchar *name;
+// } STRUCT_TAGS_FILE_MP3;
+gboolean on_match_select(GtkEntryCompletion *widget, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{  
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		GValue value = {0, };
+		gtk_tree_model_get_value(model, iter, _CONTACT_NAME_, &value);
+		g_print( "You have selected %s\n", g_value_get_string(&value) );
+		g_value_unset(&value);
+	}
+	return FALSE;
+}    
+void on_entry_tag_genre_realize( GtkWidget *widget, gpointer user_data )
+{
+	STRUCT_TAGS_FILE_MP3	*Contact;
+	GtkEntryCompletion	*completion;
+	GtkListStore		*model;
+	GtkTreeIter		iter;
+	
+	// set up completion
+	completion = gtk_entry_completion_new();
+	gtk_entry_completion_set_text_column( completion, _CONTACT_NAME_ );
+	gtk_entry_set_completion( GTK_ENTRY(widget), completion );
+	g_signal_connect( G_OBJECT(completion), "match-selected", G_CALLBACK(on_match_select), NULL );
+	g_signal_connect( G_OBJECT(widget), "changed", G_CALLBACK(on_entry_tag_genre_changed), widget );
+	model = gtk_list_store_new( 1, G_TYPE_STRING );
+	for( Contact = StructTagsFileMp3; Contact && Contact->name; Contact++ ) {
+		gtk_list_store_append( model, &iter );
+		gtk_list_store_set( model, &iter, _CONTACT_NAME_, Contact->name, -1 );
+	}
+	gtk_entry_completion_set_model( completion, GTK_TREE_MODEL(model) );
+}
 // 
 // 
 gboolean cdexpander_bool_entree_cd_verif_car = TRUE;
 // 
+// Saisie CD -> ARRANGEMENT DES TITRES DU CD
 // 
 void on_entry_new_titre_cdaudio_changed (GtkEditable *editable, gpointer user_data)
 {
@@ -575,6 +563,10 @@ void on_entry_tag_nom_artiste_realize (GtkWidget *widget, gpointer user_data)
 void on_entry_tag_commentaire_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_tag_commentaire = widget;
+	if( NULL == Config.StringCommentCD ) {
+		Config.StringCommentCD = g_strdup( " " );
+	}
+	gtk_entry_set_text( GTK_ENTRY(var_cd.Adr_entry_tag_commentaire), Config.StringCommentCD );
 }
 // 
 // 
@@ -596,19 +588,6 @@ void on_entry_tag_titre_fichier_m3u_realize (GtkWidget *widget, gpointer user_da
 }
 // 
 // 
-void on_combobox_tag_genre_cd_realize (GtkWidget *widget, gpointer user_data)
-{
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	
-	tags_set_elements_combobox (widget);
-	// tags_set_elements_comboboxCD (widget);
-	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
-	
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
-	var_cd.Adr_combobox_tag_genre_cd = GTK_COMBO_BOX (widget);
-}
-// 
-// 
 void on_entry_new_titre_cdaudio_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_new_titre_cdaudio = widget;
@@ -637,5 +616,27 @@ void on_combobox_choice_file_cue_realize (GtkWidget *widget, gpointer user_data)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "MPC");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 }
+// 
+// 
+void on_button_tag_call_popup_clicked( GtkButton *button, gpointer user_data )
+{
+	popup_menu_cd();
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
