@@ -30,32 +30,19 @@
 
 
 typedef struct {
-
 	gchar		*PathNameSrc;		// Le fichier a normaliser
 	gchar		*PathNameDest;		// Destination du fichier
 	CD_AUDIO	*Audio;
-	
 } VAR_CD_NORMALISE_ELEMENT;
 
-typedef struct {
-	
-	GList	*ListPeakGroup;		// Pointeur sur AUDIO
-	gint	 MaxElements;		// 
-	gint	 NumExtract;		// 
-	gchar	*TmpRep;		// Le dossier temporaire
-	
-} VAR_CD_NORMALISE;
 
-extern VAR_CD_NORMALISE VarCdNormalise;
-
-
-void      CdNormalise_set_list_PeakGroup (CD_AUDIO *Audio);
-void      CdNormalise_set_list_collectif_remove (void);
-gboolean  CdNormalise_list_PeakGroup_is_ready (void);
-gboolean  CdNormalise_get_is_list_PeakGroup (void);
-GList    *CdNormalise_get_list_PeakGroup (void);
-void      CdNormalise_set_normalise_ok (void);
-void      CdNormalise_add_PeakGroup (void);
+void		CdNormalise_set_list_PeakGroup (CD_AUDIO *Audio);
+void		CdNormalise_set_list_collectif_remove (void);
+gboolean	CdNormalise_list_PeakGroup_is_ready (void);
+gboolean	CdNormalise_get_is_list_PeakGroup (void);
+GList		*CdNormalise_get_list_PeakGroup (void);
+void		CdNormalise_set_normalise_ok (void);
+void		CdNormalise_add_PeakGroup (void);
 
 #endif
 
