@@ -52,6 +52,7 @@
 #include "options.h"
 #include "cd_audio.h"
 #include "configuser.h"
+#include "global.h"
 
 
 
@@ -153,11 +154,12 @@ VAR_CONFIG Config = {
 	NULL,		// PathPochette
 	FALSE,		// gboolean	BoolCheckbuttonEndOfConvert
 	NULL,		// gchar	*PathMusicFileEndOfConvert
-	NULL		// gchar	*FileMusicFileEndOfConvert
+	NULL,		// gchar	*FileMusicFileEndOfConvert
+	NULL		// gchar	*StringCommentCD
 };
 
 
-	
+
 // TRUE SI p_dest EST DANS p_src SINON FALSE
 //
 gboolean config_new_strcmp (gchar *p_src, gchar *p_dest)
@@ -198,12 +200,30 @@ void config_print_data (gchar *p_str)
 }
 // RETOURNE LE NOM COMPLET DU FICHIER DE CONFIGURATION
 // 
-gchar *config_get_pathname( void )
+/*
+gchar *OLD_config_get_pathname( void )
 {
 	// @Tetsumaki : http://forum.ubuntu-fr.org/viewtopic.php?pid=3890967#p3890967
 	// return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/xcfa_new/xcfa.conf"));
 	return( (gchar *)g_strdup_printf( "%s/%s", getenv( "HOME"), ".config/xcfa/xcfa.conf" ));
 }
+gchar *config_get_pathname( void )
+{
+	const	gchar *Lenv = NULL;
+	gchar	*Lpath = NULL;
+	
+	if( NULL != ( Lenv = g_getenv( "XDG_CONFIG_HOME" ))) {
+		Lpath = g_strdup_printf("%s/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
+	}
+	else if( NULL != ( Lenv = g_getenv( "HOME" ))) {
+		Lpath = g_strdup_printf("%s/.config/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
+	}
+	PRINT_FUNC_LF();
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print( "\t(gchar *)Lpath = %s\n", Lpath );
+	return( (gchar *)Lpath );
+}
+*/
 // RETOURNE UNE DEFINITION DU FICHIER DE CONFIGURATION
 // 
 gchar *config_get_target( gchar *p_buf )
@@ -250,8 +270,10 @@ gboolean config_read_value_bool( gchar *p_Search, gboolean *p_ValueBool )
 				*p_ValueBool = config_get_bool( Ptr );
 				g_free( Ptr );
 				Ptr = NULL;
-				config_print_data( p_Search );
-				g_print( "%s\n", *p_ValueBool ? "TRUE" : "FALSE" );
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					config_print_data( p_Search );
+					g_print( "%s\n", *p_ValueBool ? "TRUE" : "FALSE" );
+				}
 				*Conf.Larrbuf[ Cpt ] = '\0';
 				return( TRUE );	
 			}
@@ -278,8 +300,10 @@ gboolean config_read_value_atoi( gchar *p_Search, gint *p_ValueAtoi, gint p_Min,
 				Ptr = NULL;
 				if( p_Min > -1 && *p_ValueAtoi < p_Min ) *p_ValueAtoi = p_Min;
 				if( p_Max > -1 && *p_ValueAtoi > p_Max ) *p_ValueAtoi = p_Max;
-				config_print_data( p_Search );
-				g_print( "%d\n", *p_ValueAtoi ? *p_ValueAtoi : 0 );
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					config_print_data( p_Search );
+					g_print( "%d\n", *p_ValueAtoi ? *p_ValueAtoi : 0 );
+				}
 				*Conf.Larrbuf[ Cpt ] = '\0';
 				return( TRUE );
 			}
@@ -304,18 +328,20 @@ gboolean config_read_value_path( gchar *p_Search, gchar **p_ValuePath, gchar *p_
 				if( TRUE == libutils_test_dir_exist( Ptr )) {
 					*p_ValuePath = Ptr;
 				} else {
-					if( NULL == p_default )	*p_ValuePath = g_strdup( getenv( "HOME" ));
+					if( NULL == p_default )	*p_ValuePath = g_strdup( g_getenv( "HOME" ));
 					else			*p_ValuePath = g_strdup( p_default );
 					g_free( Ptr );
 					Ptr = NULL;
 				}
 			}
 			else {
-				if( NULL == p_default )	*p_ValuePath = g_strdup( getenv( "HOME" ));
+				if( NULL == p_default )	*p_ValuePath = g_strdup( g_getenv( "HOME" ));
 				else			*p_ValuePath = g_strdup( p_default );
 			}
-			config_print_data( p_Search );
-			g_print( "%s\n", *p_ValuePath ? *p_ValuePath : "" );
+			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+				config_print_data( p_Search );
+				g_print( "%s\n", *p_ValuePath ? *p_ValuePath : "" );
+			}
 			*Conf.Larrbuf[ Cpt ] = '\0';
 			return( TRUE );	
 		}
@@ -339,8 +365,10 @@ gboolean config_read_value_str( gchar *p_Search, gchar **p_ValueStr )
 				*p_ValueStr = g_strdup( Ptr );
 				g_free( Ptr );
 				Ptr = NULL;
-				config_print_data( p_Search );
-				g_print( "%s\n", *p_ValueStr ? *p_ValueStr : "" );
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					config_print_data( p_Search );
+					g_print( "%s\n", *p_ValueStr ? *p_ValueStr : "" );
+				}
 				*Conf.Larrbuf[ Cpt ] = '\0';
 				return( TRUE );	
 			}
@@ -384,7 +412,7 @@ gboolean config_open_conf_file( gchar *p_PathNameConfig )
 void config_verif_path (gchar **p_ValuePath, gchar *p_default)
 {
 	if( NULL == *p_ValuePath ) {
-		if( NULL == p_default )	*p_ValuePath = g_strdup( getenv( "HOME" ));
+		if( NULL == p_default )	*p_ValuePath = g_strdup( g_getenv( "HOME" ));
 		else			*p_ValuePath = g_strdup( p_default );
 	}
 }
@@ -394,14 +422,17 @@ void config_verif_path (gchar **p_ValuePath, gchar *p_default)
 // 
 void config_read( void )
 {
-	gchar	*PathNameConfig = config_get_pathname ();	// HOME /.config/xcfa/xcfa.conf
+	// gchar	*PathNameConfig = config_get_pathname ();	// HOME /.config/xcfa/xcfa.conf
+	gchar	*PathNameConfig = xdg_search_config_xdg();		// HOME /.config/xcfa/xcfa.conf
 	
 	// Pour les restitutions par defaut
 	g_memmove (&ConfigSaveToRest, &Config, sizeof (VAR_CONFIG));
 	
-	g_print ("\n------------------------------------------------------------------------\n" );
-	g_print ("%s\n", PathNameConfig);
-	g_print ("------------------------------------------------------------------------\n" );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("\n------------------------------------------------------------------------\n" );
+		g_print ("%s\n", PathNameConfig);
+		g_print ("------------------------------------------------------------------------\n" );
+	}
 	
 	// IF NOT EXIST CONFIG-FILE
 	if( FALSE == libutils_test_file_exist( PathNameConfig )) {
@@ -532,6 +563,7 @@ void config_read( void )
 		config_read_value_str( "STRING_ENTRY_PROXY_PORT",		&Config.entry_proxy_port );
 		config_read_value_str( "NAME_IMG",				&Config.NameImg );
 		config_read_value_str( "FILE_NAME_MUSIC_END_CONVERT",		&Config.FileMusicFileEndOfConvert );
+		config_read_value_str( "STRING_COMMENT_CD",			&Config.StringCommentCD );
 		
 		config_close_conf_file();
 		
@@ -557,14 +589,17 @@ void config_read( void )
 		config_verif_path( &Config.PathSaveImg,			NULL );
 		config_verif_path( &Config.PathMusicFileEndOfConvert,	NULL );
 	}
-	g_free( PathNameConfig );
-	PathNameConfig = NULL;
+	if( NULL != PathNameConfig ) {
+		g_free( PathNameConfig );
+		PathNameConfig = NULL;
+	}
 }
 //  SAUVEGARDE DU FICHIER DE CONFIGURATION
 // 
 void config_save( void )
 {
-	gchar	*PathNameConfig = config_get_pathname();	// HOME /.config/xcfa/xcfa.conf
+	// gchar	*PathNameConfig = config_get_pathname();	// HOME /.config/xcfa/xcfa.conf
+	gchar	*PathNameConfig = xdg_search_config_xdg();		// HOME /.config/xcfa/xcfa.conf
 	FILE	*fp;
 	gchar	*Ptr = NULL;
 	
@@ -697,6 +732,7 @@ void config_save( void )
 		fprintf( fp, "BOOL_PLAY_MUSIC_END_CONVERT         = %s\n", Config.BoolCheckbuttonEndOfConvert == TRUE ? "TRUE" : "FALSE" );
 		fprintf( fp, "PATH_MUSIC_END_CONVERT              = %s\n", Config.PathMusicFileEndOfConvert != NULL ? Config.PathMusicFileEndOfConvert : "" );
 		fprintf( fp, "FILE_NAME_MUSIC_END_CONVERT         = %s\n", Config.FileMusicFileEndOfConvert != NULL ? Config.FileMusicFileEndOfConvert : "" );
+		fprintf( fp, "STRING_COMMENT_CD                   = %s\n", Config.StringCommentCD  != NULL ? Config.StringCommentCD : "" );
 		
 		// TODO: RESERVED
 		// g_sprintf( String, "%08lx", ret );
@@ -707,8 +743,10 @@ void config_save( void )
 		fprintf( fp, "\n" );
 		fclose( fp );
 	}
-	g_free( PathNameConfig );
-	PathNameConfig = NULL;
+	if( NULL != PathNameConfig ) {
+		g_free( PathNameConfig );
+		PathNameConfig = NULL;
+	}
 }
 // LIBERATION MEMOIRE
 // 
@@ -757,8 +795,8 @@ void config_remove( void )
 	g_free( Config.PathSaveImg );			Config.PathSaveImg = NULL;
 	g_free( Config.PathMusicFileEndOfConvert );	Config.PathMusicFileEndOfConvert  = NULL;	
 	g_free( Config.FileMusicFileEndOfConvert );	Config.FileMusicFileEndOfConvert = NULL;
+	g_free( Config.StringCommentCD );		Config.StringCommentCD = NULL;
 }
-	
 
 
 
