@@ -1997,22 +1997,24 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 	}
 	
 	// INFORMATION
-	g_print ("!-----------------------------------------------------------!\n");
-	if (WithParameter == TRUE)
-	g_print ("!  --With Expert Parameters--\n");
-	else
-	g_print ("!  --Without Expert Parameters--\n");
-	g_print ("!  %s\n", info);
-	g_print ("!-----------------------------------------------------------!\n");
-	g_print ("!  ");
-	for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
-		g_print ("%s ", conv.ArgConv[ pos ]);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("!-----------------------------------------------------------!\n");
+		if (WithParameter == TRUE)
+		g_print ("!  --With Expert Parameters--\n");
+		else
+		g_print ("!  --Without Expert Parameters--\n");
+		g_print ("!  %s\n", info);
+		g_print ("!-----------------------------------------------------------!\n");
+		g_print ("!  ");
+		for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
+			g_print ("%s ", conv.ArgConv[ pos ]);
+		}
+		g_print ("\n!-----------------------------------------------------------!\n");
+		for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
+			g_print ("ArgConv[ %02d ] = %s\n", pos, conv.ArgConv[ pos ]);
+		}
+		g_print ("\n");
 	}
-	g_print ("\n!-----------------------------------------------------------!\n");
-	for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
-		g_print ("ArgConv[ %02d ] = %s\n", pos, conv.ArgConv[ pos ]);
-	}
-	g_print ("\n");
 
 	switch (type_conv) {
 	case NONE_CONV :
@@ -2360,19 +2362,20 @@ gboolean conv_exec_extract (gboolean WithParameter, TYPE_CONV type_conv, gchar *
 	conv.BoolIsExtract = TRUE;
 		
 	/* Infos */
-	g_print ("!-----------------------------------------------------------!\n");
-	if (WithParameter == TRUE)
-	g_print ("!  --With Expert Parameters--\n");
-	else
-	g_print ("!  --Without Expert Parameters--\n");
-	g_print ("!  %s\n", info);
-	g_print ("!-----------------------------------------------------------!\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("!-----------------------------------------------------------!\n");
+		if (WithParameter == TRUE)
+		g_print ("!  --With Expert Parameters--\n");
+		else
+		g_print ("!  --Without Expert Parameters--\n");
+		g_print ("!  %s\n", info);
+		g_print ("!-----------------------------------------------------------!\n");
 
-	for (pos = 0; conv.ArgExtract[ pos ] != NULL; pos ++) {
-		g_print ("ArgExtract[ %02d ] = %s\n", pos, conv.ArgExtract[ pos ]);
+		for (pos = 0; conv.ArgExtract[ pos ] != NULL; pos ++) {
+			g_print ("ArgExtract[ %02d ] = %s\n", pos, conv.ArgExtract[ pos ]);
+		}
+		g_print ("\n");
 	}
-	g_print ("\n");
-
 	if (type_conv == CDPARANOIA_CD_TO_WAV || type_conv == CDPARANOIA_CD_TO_WAV_EXPERT)
 		conv_with_cdparanoia_ARGS (conv.ArgExtract);
 	else if (type_conv == CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT)
@@ -2419,7 +2422,8 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 	blk = size / BUFSIZ;
 	// conv.conversion_percent = 0.;
 	PRINT_FUNC_LF();
-	g_print ("\t%s\n\t%s\n", filesrc, filedest);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\t%s\n\t%s\n", filesrc, filedest);
 	cpt = 0;
 	conv.BoolIsCopy = TRUE;
 	while ( ! feof (fe)) {
