@@ -156,12 +156,10 @@ void dragndrop_list_drag_data (GtkWidget *widget, gchar *string)
 		
 		else if( widget == view.Adr_viewport_image_preview ) {
 			
-			PRINT("FROM widget == view.Adr_viewport_image_preview\n");
 			pochedir_add_img_file (List);
 		}
 		else if( widget == view.AdrDrawingarea ) {
 			
-			PRINT("FROM widget == view.AdrDrawingarea");
 			poche_add_img_file_to_Drawingarea (List);
 		}
 		
