@@ -63,7 +63,6 @@ gint filelc_get_command_line_remove (void)
 {
 	gint	pos = 0;
 	
-	// pos < MAX_ARG_CONV
 	for (pos = 0; conv.ArgConv [ pos ] != NULL; pos ++) {
 		g_free (conv.ArgConv [ pos ]);
 		conv.ArgConv [ pos ] = NULL;
@@ -83,19 +82,6 @@ gint filelc_get_command_line_nice (void)
 	// RETOURNE LA PROCHANE POSITION DE pos
 	return (3);
 }
-/*
-typedef struct {
-	TYPE_CONV	 type_conv;
-	gboolean	 With_CommandLineUser;
-	gchar		*filesrc;
-	gchar		*filedest;
-	TAGS		*tags;
-	gchar		*cdrom;
-	gchar		*num_track;
-	// gboolean	 BoolSetBitrate;
-	gchar		*PtrStrBitrate;
-} PARAM_FILELC;
-*/
 // 
 // 
 gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
@@ -110,7 +96,6 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 	while (ptr && *ptr) {
 		if (*ptr == '\"') {
 			if (bool_open == TRUE) {
-				// New = g_list_append (New, g_strdup (gstr->str));
 				conv.ArgConv [ (*pos) ++ ] = g_strdup (gstr->str);
 				
 				g_string_free (gstr, TRUE);
@@ -134,7 +119,6 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 
 		if (*ptr == ' ') {
 			if (gstr != NULL && *gstr->str) {
-				// New = g_list_append (New, g_strdup (gstr->str));
 				conv.ArgConv [ (*pos) ++ ] = g_strdup (gstr->str);
 				
 				g_string_free (gstr, TRUE);
@@ -158,7 +142,6 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 
 			/* OGGENC_WAV_TO_OGG | OGGENC_FLAC_TO_OGG */
 			if (*ptr == 'b' && (*(ptr+1) == ' ' || *(ptr+1) == '\0')) {
-				// New = g_list_append (New, g_strdup_printf ("%s", optionsOggenc_get_val_bitrate_oggenc ()));
 				conv.ArgConv [ (*pos) ++ ] = g_strdup_printf ("%s", optionsOggenc_get_val_bitrate_oggenc ());
 				
 				ptr ++;
@@ -167,7 +150,6 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 			else if (*ptr == 'b' && *(ptr+1) == 'l' && (*(ptr+2) == ' ' || *(ptr+2) == '\0')) {
 				Larrbuf = g_strsplit (optionsLame_get_str_val_bitrate_abr_vbr_lame (), " ", 0);
 				for (i=0; Larrbuf[i]; i++) {
-					// New = g_list_append (New, g_strdup (Larrbuf[i]));
 					conv.ArgConv [ (*pos) ++ ] = g_strdup (Larrbuf[i]);
 					
 				}
@@ -209,7 +191,6 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 		}
 	}
 	if (gstr != NULL && *gstr->str) {
-		// New = g_list_append (New, g_strdup (gstr->str));
 		conv.ArgConv [ (*pos) ++ ] = g_strdup (gstr->str);
 		
 		g_string_free (gstr, TRUE);
@@ -379,36 +360,25 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 			param_filelc->PtrStrBitrate = NULL;
 		}
 		
+		
 		if (Config.BoolArtistTag || Config.BoolTitleTag || Config.BoolAlbumTag ||
 		    Config.BoolNumerateTag || Config.BoolGenreTag || Config.BoolYearTag || Config.BoolCommentTag) {
 			conv.ArgConv [ pos++ ] = g_strdup ("--add-id3v2");
 		}
 		
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Artist);
-			// if (*Ptr != '\0') {
-				conv.ArgConv [ pos++ ] = g_strdup ("--ta");
-				conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
-			// }
-			// g_free (Ptr);	Ptr = NULL;
+			conv.ArgConv [ pos++ ] = g_strdup ("--ta");
+			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
 		}
 		
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Title);
-			// if (*Ptr != '\0') {
-				conv.ArgConv [ pos++ ] = g_strdup ("--tt");
-				conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
-			// }
-			// g_free (Ptr);	Ptr = NULL;
+			conv.ArgConv [ pos++ ] = g_strdup ("--tt");
+			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Album);
-			// if (*Ptr != '\0') {
-				conv.ArgConv [ pos++ ] = g_strdup ("--tl");
-				conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
-			// }
-			// g_free (Ptr);	Ptr = NULL;
+			conv.ArgConv [ pos++ ] = g_strdup ("--tl");
+			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
 		
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->Number && *param_filelc->tags->Number) {
@@ -438,12 +408,8 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 		}
 		
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Comment);
-			// if (*Ptr != '\0') {
-				conv.ArgConv [ pos++ ] = g_strdup ("--tc");
-				conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
-			// }
-			// g_free (Ptr);	Ptr = NULL;
+			conv.ArgConv [ pos++ ] = g_strdup ("--tc");
+			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
 		
 		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
@@ -554,54 +520,40 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 		conv.ArgConv [ pos++ ] = g_strdup ("faac");
 		
 		// filelc_analyse_line (entry, New, param_filelc->tags);
-		// -----------------
+		// -----------------------------------------------------
 		
 		if ('-' == *OptionsFaac_get_faac_conteneur ()) {
-			// New = g_list_append (New, g_strdup_printf ("%s", OptionsFaac_get_faac_conteneur ()));
 			conv.ArgConv [ pos++ ] = g_strdup (OptionsFaac_get_faac_conteneur ());
 		}
 		
 		Ptr = OptionsFaac_get_faac_set_choice_vbr_abr ();
 		if ( *(Ptr + 1) == 'b') {
-			// New = g_list_append (New, g_strdup ("-b"));
 			conv.ArgConv [ pos++ ] = g_strdup ("-b");
 		}
 		else {
-			// New = g_list_append (New, g_strdup ("-q"));
 			conv.ArgConv [ pos++ ] = g_strdup ("-q");
 		}
-		// New = g_list_append (New, g_strdup_printf ("%s", (Ptr +3)));
 		conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", (Ptr +3));
 		
 		
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			// New = g_list_append (New, g_strdup ("--artist"));
 			conv.ArgConv [ pos++ ] = g_strdup ("--artist");
-			// New = g_list_append (New, g_strdup_printf ("%s", param_filelc->tags->Artist));
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			// New = g_list_append (New, g_strdup ("--title"));
 			conv.ArgConv [ pos++ ] = g_strdup ("--title");
-			// New = g_list_append (New, g_strdup_printf ("%s", param_filelc->tags->Title));
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			// New = g_list_append (New, g_strdup ("--album"));
 			conv.ArgConv [ pos++ ] = g_strdup ("--album");
-			// New = g_list_append (New, g_strdup_printf ("%s", param_filelc->tags->Album));
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
-			// New = g_list_append (New, g_strdup ("--genre"));
 			conv.ArgConv [ pos++ ] = g_strdup ("--genre");
-			// New = g_list_append (New, g_strdup_printf ("%s", param_filelc->tags->Genre));
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Genre);
 		}
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			// New = g_list_append (New, g_strdup ("--year"));
 			conv.ArgConv [ pos++ ] = g_strdup ("--year");
-			// New = g_list_append (New, g_strdup_printf ("%s", param_filelc->tags->Year));
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Year);
 		}
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->IntNumber > -1) {
@@ -609,9 +561,7 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 			conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", param_filelc->tags->IntNumber);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			// New = g_list_append (New, g_strdup ("--comment"));
 			conv.ArgConv [ pos++ ] = g_strdup ("--comment");
-			// New = g_list_append (New, g_strdup_printf ("%s", param_filelc->tags->Comment));
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
 
@@ -625,33 +575,20 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 	else if (param_filelc->type_conv == MPPENC_WAV_TO_MPC) {
 		
 		pos = filelc_get_command_line_nice ();
-		// conv.ArgConv [ pos++ ] = g_strdup ("mppenc");
 		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_musepack_tools_mppenc));
 		conv.ArgConv [ pos++ ] = g_strdup ("--verbose");
 		conv.ArgConv [ pos++ ] = g_strdup ("--overwrite");
 		conv.ArgConv [ pos++ ] = g_strdup (optionsMusepack_get_quality_mppenc ());
 
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			// New = g_list_append (New, g_strdup ("--artist"));
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Artist);
-			// New = g_list_append (New, g_strdup_printf ("%s", Ptr));
-			// g_free (Ptr);	Ptr = NULL;
 			conv.ArgConv [ pos++ ] = g_strdup ("--artist");
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			// New = g_list_append (New, g_strdup ("--title"));
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Title);
-			// New = g_list_append (New, g_strdup_printf ("%s", Ptr));
-			// g_free (Ptr);	Ptr = NULL;
 			conv.ArgConv [ pos++ ] = g_strdup ("--title");
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			// New = g_list_append (New, g_strdup ("--album"));
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Album);
-			// New = g_list_append (New, g_strdup_printf ("%s", Ptr));
-			// g_free (Ptr);	Ptr = NULL;
 			conv.ArgConv [ pos++ ] = g_strdup ("--album");
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
@@ -668,10 +605,6 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Number);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			// New = g_list_append (New, g_strdup ("--comment"));
-			// Ptr = utils_convert_from_utf8 (param_filelc->tags->Comment);
-			// New = g_list_append (New, g_strdup_printf ("%s", Ptr));
-			// g_free (Ptr);	Ptr = NULL;
 			conv.ArgConv [ pos++ ] = g_strdup ("--comment");
 			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
@@ -909,31 +842,3 @@ GList *filelc_remove_glist (GList *New)
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
