@@ -578,7 +578,7 @@ void FileMp3Ogg_affiche_glist (void)
 									 detail->TypeMp3Ogg.mode [ 0 ]);
 			}
 			
-			NameDest = libutils_get_name_without_ext (detail->namefile);
+			NameDest = libutils_get_name_without_ext_with_amp (detail->namefile);
 			
 			gtk_list_store_append (var_file_mp3ogg.Adr_List_Store, &iter);
 			gtk_list_store_set (var_file_mp3ogg.Adr_List_Store, &iter,
