@@ -238,6 +238,8 @@ static gint filemp3oggconv_timeout (gpointer data)
 	if (TRUE == conv.bool_percent_conv) {
 		gchar	*Str = NULL;
 		
+		// DEBUG
+		if( conv.total_percent > 1.0 ) conv.total_percent = 1.0;
 		Str = g_strdup_printf ("%d%%", (int)(conv.total_percent * 100));
 		WindScan_set_progress (Str, conv.total_percent);
 		g_free (Str);
