@@ -25,6 +25,31 @@
  */
 
 
+
+
+
+/*
+void main_trash (void )
+{
+	GFile		*file = NULL;
+	
+	file = g_file_new_for_path( "/home/cat/coucou.txt" ); 
+	if( FALSE == g_file_trash( file, NULL, NULL )) {
+		g_print("TRASH BAD\n");
+	}
+	else {
+		g_print("TRASH OK\n");
+	}
+
+        g_object_unref( file );
+}
+*/
+
+
+
+
+
+
 #ifdef HAVE_CONFIG_H
 	#include "../config.h"
 #endif
@@ -188,27 +213,33 @@ void filetrash_test_trash_is_ok (void)
 	gchar        *StrTrash = NULL;
 	gint          Dummy;
 	
-	g_print ("\n[ Trash ]\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\n[ Trash ]\n");
 	
 	if (var_filetrash.BoolTrashIsOk == TRUE) return;
 	var_filetrash.BoolTrashIsOk = TRUE;
 	var_filetrash.Bool_kde_full_session = filetrash_test_desktop_is_kde ();
 	
-	g_print ("KDE SESSION : %s\n", var_filetrash.Bool_kde_full_session ? "TRUE" : "FALSE");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("KDE SESSION : %s\n", var_filetrash.Bool_kde_full_session ? "TRUE" : "FALSE");
 
 	Path = g_strdup_printf ("%s/.Trash", getenv ("HOME"));
 	BoolExistTrashOLD = libutils_test_dir_exist (Path);
-	if (BoolExistTrashOLD == TRUE)
-		g_print ("EXIST ......: %s\n", Path);
-	else	g_print ("NOT EXIST ..: %s\n", Path);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		if (BoolExistTrashOLD == TRUE)
+			g_print ("EXIST ......: %s\n", Path);
+		else	g_print ("NOT EXIST ..: %s\n", Path);
+	}
 	g_free (Path);
 	Path = NULL;
 	
 	Path = g_strdup_printf ("%s/.local/share/Trash/files", getenv ("HOME"));
 	BoolExistTrashNEW = libutils_test_dir_exist (Path);
-	if (BoolExistTrashNEW == TRUE)
-		g_print ("EXIST ......: %s\n", Path);
-	else	g_print ("NOT EXIST ..: %s\n", Path);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		if (BoolExistTrashNEW == TRUE)
+			g_print ("EXIST ......: %s\n", Path);
+		else	g_print ("NOT EXIST ..: %s\n", Path);
+	}
 	g_free (Path);
 	Path = NULL;
 	
@@ -240,7 +271,8 @@ void filetrash_test_trash_is_ok (void)
 		}
 	}
 	
-	g_print ("---\nUSE ........: %s\n---\n\n", filetrash_get_trash ());
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("---\nUSE ........: %s\n---\n\n", filetrash_get_trash ());
 }
 // 
 // 
