@@ -970,7 +970,7 @@ void on_scrolledwindow_file_wav_realize (GtkWidget *widget, gpointer user_data)
 	
 	var_file_wav.Adr_scroll = widget;
 	
-	var_file_wav.Pixbuf_NotInstall             = libutils_init_pixbufs ("xcfa/not_install.png");
+	var_file_wav.Pixbuf_NotInstall             = libutils_init_pixbufs ("not_install.png");
 	
 	var_file_wav.Adr_List_Store = store =
 	gtk_list_store_new (	COLUMN_FILE_NUM,	/* TOTAL NUMBER			*/
