@@ -241,6 +241,8 @@ static gint filewavconv_timeout (gpointer data)
 	
 		gchar *Str = NULL;
 		
+		// DEBUG
+		if( conv.total_percent > 1.0 ) conv.total_percent = 1.0;
 		Str = g_strdup_printf ("%d%%", (gint)(conv.total_percent * 100));
 		WindScan_set_progress (Str, conv.total_percent);
 		g_free (Str);
