@@ -87,10 +87,11 @@ extern	GtkWidget	*AdrLabelStatusbarGlobal;
 //  DEBUG
 // ---------------------------------------------------------------------------
 // 
-#define PRINT_FUNC_LF() g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__)
+#define PRINT_FUNC_LF() if( TRUE == OptionsCommandLine.BoolVerboseMode ) g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__)
 #define PRINTINT(str,num) g_print ("%s = %d\n", str, num)
 #define PRINTBOOL(str,bool) g_print ("%s = %s\n", str, bool == TRUE ? "TRUE" : "FALSE")
-#define PRINT(str) g_print ("%s :: %s(line = %d)\n\t%s\n", __FILE__, __FUNCTION__, __LINE__, str)
+#define PRINT(str) if( TRUE == OptionsCommandLine.BoolVerboseMode ) g_print ("%s :: %s(line = %d)\n\t%s\n", __FILE__, __FUNCTION__, __LINE__, str)
+#define	VERBOSE(str) if( TRUE == OptionsCommandLine.BoolVerboseMode ) g_print( "%s", str );
 
 // 
 // ---------------------------------------------------------------------------
@@ -128,16 +129,18 @@ typedef struct {
 extern KEYS keys;
 
 typedef struct {
-	gchar      Machine [ 100 ];
-	gint       NbCpu;
-	gint       TypeCpu;
-	gboolean   BoolCpuIs64Bits;
+	gchar		Machine [ 100 ];
+	gint		NbCpu;
+	gint		TypeCpu;
+	gboolean	BoolCpuIs64Bits;
 	
 } HOST_CONF;
 
 extern HOST_CONF HostConf;
 
 
+
+
 // 
 // ---------------------------------------------------------------------------
 //  Dossier temporaire
