@@ -80,6 +80,7 @@ GtkWidget	*WindMain = NULL;
 HOST_CONF	 HostConf;
 GtkWidget	*AdrLabelStatusbarGlobal = NULL;
 
+
 KEYS keys = {
 	FALSE,		// gboolean	BoolGDKPress
 	FALSE,		// gboolean	BoolGDK_Control_L_R
@@ -104,84 +105,86 @@ void remove_memory_apply (void)
 	if (TRUE == BoolDoEnterRemove) return;
 	BoolDoEnterRemove = TRUE;
 	
-	g_print ("\n--------------------------------------------------\n");
+	VERBOSE ("\n--------------------------------------------------\n");
 	PRINT_FUNC_LF();
-	g_print ("--------------------------------------------------\n");
+	VERBOSE ("--------------------------------------------------\n");
 	
-	g_print ("AlsaPlay_stop ()\n");
+	VERBOSE("AlsaPlay_stop ()\n")
 	AlsaPlay_stop ();
 	
-	g_print ("split_set_stop ()\n");
+	VERBOSE ("split_set_stop ()\n");
 	split_set_stop ();
 	
-	g_print ("Recuperation position et taille de la fenetre\n");
+	VERBOSE ("Recuperation position et taille de la fenetre\n");
 	gdk_window_get_root_origin (WindMain->window, &Config.WinPos_X, &Config.WinPos_Y);
 	gdk_window_get_size (WindMain->window, &Config.WinWidth, &Config.WinHeight);	
 	
-	g_print ("Sauvegarde l'etat de l'expander CD\n");
+	VERBOSE ("Sauvegarde l'etat de l'expander CD\n");
 	Config.BoolEtatExpanderCd = gtk_expander_get_expanded (GTK_EXPANDER (var_cd.Adr_Expander));
 	
-	g_print ("Sauvegarde de la configuration\n");
+	VERBOSE ("Sauvegarde de la configuration\n");
 	config_save ();
 	
-	g_print ("config_remove ()\n");
+	VERBOSE ("config_remove ()\n");
 	config_remove ();
 	
-	g_print ("fileanalyze_remove_entetefile ()\n");
+	VERBOSE ("fileanalyze_remove_entetefile ()\n");
 	fileanalyze_remove_entetefile ();
 
-	g_print ("dvdaudio_remove_GtkTree ()\n");
+	VERBOSE ("dvdaudio_remove_GtkTree ()\n");
 	dvd_remove_GtkTree ();
-	g_print ("dvdread_remove_list ()\n");
+	VERBOSE ("dvdread_remove_list ()\n");
 	dvdread_remove_list ();
 
-	g_print ("cdaudio_deallocate_glist ()\n");
+	VERBOSE ("cdaudio_deallocate_glist ()\n");
 	cdaudio_deallocate_glist ();
 
-	g_print ("NotifySend_remove ()\n");
+	VERBOSE ("NotifySend_remove ()\n");
 	NotifySend_remove ();
 	
-	g_print ("Parse_remove (PARSE_TYPE_STOCKAGE_CD)\n");
-	Parse_remove (PARSE_TYPE_STOCKAGE_CD);
-	g_print ("Parse_remove (PARSE_TYPE_TITLE_CD)\n");
-	Parse_remove (PARSE_TYPE_TITLE_CD);
+	VERBOSE ("Parse_remove (PARSE_TYPE_STOCKAGE_CD)\n");
+	Parse_remove (PARSE_TYPE_STOCKAGE_CD, TRUE);
+	VERBOSE ("Parse_remove (PARSE_TYPE_TITLE_CD)\n");
+	Parse_remove (PARSE_TYPE_TITLE_CD, TRUE);
 	
-	g_print ("poche_remove_view()\n");
+	VERBOSE ("poche_remove_view()\n");
 	poche_remove_view();
 	
-	g_print ("poche_remove_ListImage()\n");
+	VERBOSE ("poche_remove_ListImage()\n");
 	poche_remove_ListImage();
 
-	g_print ("libcombo_remove ()\n");
+	VERBOSE ("libcombo_remove ()\n");
 	libcombo_remove ();
 
-	g_print ("scan_remove_glist_media ()\n");
+	VERBOSE ("scan_remove_glist_media ()\n");
 	scan_remove_glist_media ();
 
-	g_print ("web_remove_temporary_rep ()\n");
+	VERBOSE ("web_remove_temporary_rep ()\n");
 	web_remove_temporary_rep ();
 	
-	g_print ("CdCurl_remove_struct_all ()\n");
+	VERBOSE ("CdCurl_remove_struct_all ()\n");
 	CdCurl_remove_struct_all();
 	
-	g_print ("mplayer_remove_list_args ()\n");
+	VERBOSE ("mplayer_remove_list_args ()\n");
 	mplayer_remove_list_args ();
 	
-	g_print ("SplitSpectre_remove ()\n");
+	VERBOSE ("SplitSpectre_remove ()\n");
 	SplitSpectre_remove ();
 	
-	g_print ("AlsaPlay_remove ()\n");
+	VERBOSE ("AlsaPlay_remove ()\n");
 	AlsaPlay_remove ();
 		
 	if (TRUE == libutils_test_file_exist (XCFA_FILE_LOAD)) {
-		g_print ("g_unlink (%s)\n", XCFA_FILE_LOAD);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) 
+			g_print ("g_unlink (%s)\n", XCFA_FILE_LOAD);
 		g_unlink (XCFA_FILE_LOAD);
 	}
 	if (TRUE == libutils_test_file_exist (SPLIT_FILE_TMP_WAV)) {
-		g_print ("g_unlink (%s)\n", SPLIT_FILE_TMP_WAV);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) 
+			g_print ("g_unlink (%s)\n", SPLIT_FILE_TMP_WAV);
 		g_unlink (SPLIT_FILE_TMP_WAV);
 	}
-	g_print ("StatusBar_remove ()\n");
+	VERBOSE ("StatusBar_remove ()\n");
 	StatusBar_remove();
 
 	Config.PathPochette = libutils_remove_temporary_rep( Config.PathPochette );
@@ -381,29 +384,55 @@ void AnalyseCommandLine_set_argv (int argc, gchar *argv[])
 	gint	 i;
 	gchar	*str_current_dir = NULL;
 	FILE	*fp = NULL;
-	
-	if (optind < argc) {
-		str_current_dir = g_get_current_dir ();
-		fp = fopen (XCFA_FILE_LOAD, "a");
-		for (i = optind; i < argc; i++)
-		{
-			if (argv[i][0] == '/') {
-
-				fprintf (fp, "%s\n", argv[ i ]);
+		
+	if( optind < argc ) {
+		
+		for( i = optind; i < argc; i++ ) {
+			// VERBOSE MODE
+			if( 0 == strcmp( argv[i], "-verbose" )) {
+				OptionsCommandLine.BoolVerboseMode = TRUE;
+				// g_print( "\nVERBOSE MODE:\n");
+				// g_print( "	argv[ %d ] = %s\n", i, argv[ i ] );
+				// g_print( "	BoolVerboseMode = %s\n", OptionsCommandLine.BoolVerboseMode ? "TRUE" : "FALSE" );
+				// g_print( "\n" );
 			}
-			else {
-				gchar *str = NULL;
-				
-				str = g_strdup_printf ("%s/%s", str_current_dir, argv[i]);
-				fprintf (fp, "%s\n", str);
-				g_free (str);
-				str = NULL;
+			// VERSION MODE
+			else if( 0 == strcmp( argv[i], "-version" )) {
+				OptionsCommandLine.BoolVersionMode = TRUE;
+				// g_print( "\nVERSION MODE:\n");
+				// g_print( "	argv[ %d ] = %s\n", i, argv[ i ] );
+				// g_print( "	OptionsCommandLine.BoolVersionMode = %s\n", OptionsCommandLine.BoolVersionMode ? "TRUE" : "FALSE" );
+				// g_print( "\n" );
+			}
+			// HELP MODE
+			else if( 0 == strcmp( argv[i], "-help" ) || 0 == strcmp( argv[i], "-h" )) {
+				OptionsCommandLine.BoolHelpMode = TRUE;
 			}
 		}
-		fclose (fp);
+		if( FALSE == OptionsCommandLine.BoolVerboseMode && FALSE == OptionsCommandLine.BoolVersionMode ) {
+			str_current_dir = g_get_current_dir();
+			fp = fopen( XCFA_FILE_LOAD, "a" );
+			for( i = optind; i < argc; i++ )
+			{
+				// FROM DESKTOP
+				if( argv[i][0] == '/' ) {
+
+					fprintf( fp, "%s\n", argv[ i ] );
+				}
+				else {
+					gchar *str = NULL;
+				
+					str = g_strdup_printf( "%s/%s", str_current_dir, argv[i] );
+					fprintf( fp, "%s\n", str );
+					g_free( str );
+					str = NULL;
+				}
+			}
+			fclose( fp );
+			g_free( str_current_dir );
+			str_current_dir = NULL;
+		}
 	}
-	g_free (str_current_dir);
-	str_current_dir = NULL;
 }
 /* gint main (gint argc, gchar *argv[], gchar **envp)
  *
@@ -420,9 +449,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gchar	*Path = NULL;
 	gchar	*PackageVersion = NULL;
 
-	
 	if (TRUE == process_exist_file ()) {
-		
 		AnalyseCommandLine_set_argv (argc, &argv[0]);		// Get and save param-file
 		return (EXIT_SUCCESS);					// Quit process with success
 	}
@@ -446,11 +473,26 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	g_print ("Gtk version  = %d.%d.%d\n", GTK_MAJOR_VERSION, GTK_MICRO_VERSION, GTK_MINOR_VERSION);
 	g_print ("Glib version = %d.%d.%d\n", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION);
 	g_print ("***************************\n\n");
-#ifdef ENABLE_NLS
-	g_print ("ENABLE_NLS OK\n");
-	g_print ("\tGETTEXT_PACKAGE    = %s\n", GETTEXT_PACKAGE);
-	g_print ("\tLOCALE_DIR         = %s\n", LOCALE_DIR);
+	
+	if( TRUE == OptionsCommandLine.BoolVersionMode || TRUE == OptionsCommandLine.BoolHelpMode ) {
+		if( TRUE == OptionsCommandLine.BoolHelpMode ) {
+			g_print( "HELP MODE:\n");
+			g_print( "	-help -h	Displays this help section and exits\n" );
+			g_print( "	-version	Displays the version of the program and exits\n" );
+			g_print( "	-verbose	Activate verbose mode\n" );
+		}
+		g_print( "\n" );
+		g_unlink( XCFA_FILE_LOAD );
+		g_unlink( SPLIT_FILE_TMP_WAV );
+		return( EXIT_SUCCESS );
+	}
 
+#ifdef ENABLE_NLS
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("ENABLE_NLS OK\n");
+		g_print ("\tGETTEXT_PACKAGE    = %s\n", GETTEXT_PACKAGE);
+		g_print ("\tLOCALE_DIR         = %s\n", LOCALE_DIR);	
+	}
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -459,11 +501,13 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	// g_error ("ENABLE_NLS IS NOT OK\n\n");
 #endif
 	GetInfo_cpu_print ();
-	g_print ("\n");
-	g_print ("HostConf.NbCpu   = %d CPU\n", HostConf.NbCpu);
-	g_print ("HostConf.TypeCpu = %d Bits\n", HostConf.TypeCpu);
-	g_print ("HostConf.Machine = %s\n", HostConf.Machine);
-	g_print ("\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("\n");
+		g_print ("HostConf.NbCpu   = %d CPU\n", HostConf.NbCpu);
+		g_print ("HostConf.TypeCpu = %d Bits\n", HostConf.TypeCpu);
+		g_print ("HostConf.Machine = %s\n", HostConf.Machine);
+		g_print ("\n");
+	}
 	
 	/* IF Segmentation fault */
 	signal (SIGSEGV, segfault_handler);
@@ -482,15 +526,17 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	PathCurrentDir = g_strdup_printf ("%s/glade/%s", CurrentDir, PACKAGE_NAME_GLADE);
 	g_free (CurrentDir);
 	CurrentDir = NULL;
-	PathShareProjet = g_strdup_printf ("%s/%s/glade/%s", DATA_DIR, PACKAGE_NAME, PACKAGE_NAME_GLADE);
+	// PathShareProjet = g_strdup_printf ("%s/%s/glade/%s", DATA_DIR, PACKAGE_NAME, PACKAGE_NAME_GLADE);
+	PathShareProjet = xdg_search_data_xdg( PACKAGE_NAME_GLADE );
 
 	if (FALSE == g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS) && FALSE == g_file_test (PathShareProjet, G_FILE_TEST_EXISTS)) {
-		g_print("!---------------------------------------------------------------------------------------------------\n");
-		g_print("! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\n", PathCurrentDir);
-		g_print("!---------------------------------------------------------------------------------------------------\n");
-		g_print("! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\n", PathShareProjet);
-		g_print("!---------------------------------------------------------------------------------------------------\n");
-
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print("!---------------------------------------------------------------------------------------------------\n");
+			g_print("! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\n", PathCurrentDir);
+			g_print("!---------------------------------------------------------------------------------------------------\n");
+			g_print("! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\n", PathShareProjet);
+			g_print("!---------------------------------------------------------------------------------------------------\n");
+		}
 		g_free (PathCurrentDir);
 		PathCurrentDir = NULL;
 		g_free (PathShareProjet);
@@ -507,7 +553,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 
 		Path = PathShareProjet;
 	}
-	g_print("\nPATHNAME FILE %s: %s\n\n", PACKAGE_NAME_GLADE, Path);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print("\nPATHNAME FILE %s: %s\n\n", PACKAGE_NAME_GLADE, Path);
 	if (gtk_builder_add_from_file (GtkXcfaProjet, Path, &p_err) <= 0) {
 		g_warning ("Couldn't load builder file: %s", p_err->message);
 		g_error_free (p_err);
@@ -631,6 +678,9 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 			"");
 	}
 	
+	xdg_print_list_config_path();
+	xdg_print_list_data_path();
+	
 	gtk_main ();
 	gdk_threads_leave ();
 
