@@ -125,9 +125,11 @@ int mplayer_call_exec (gchar **args, pid_t *p, gint p_output)
 void mplayer_remove_list_args (void)
 {
 	gint	 PosArg = 0;
-
-	for (PosArg = 0; NULL != VarMplayer.PlayerArgs[ PosArg ]; PosArg ++) {
-		g_free (VarMplayer.PlayerArgs[ PosArg ]);
+	
+	for( PosArg = 0; PosArg < MAX_PLAYERS_ARGS; PosArg ++ ) {
+		if(  NULL != VarMplayer.PlayerArgs[ PosArg ] ) {
+			g_free (VarMplayer.PlayerArgs[ PosArg ]);
+		}
 		VarMplayer.PlayerArgs[ PosArg ] = NULL;
 	}
 }
@@ -166,29 +168,6 @@ void mplayer_create_fifo (void)
 	 	close (descripteur);
 	 }
 }
-/*
-void OLD_mplayer_create_fifo (void)
-{
-	gchar *args[ 10 ];
-	gint   pos = 0;
-	gint   status;
-	pid_t  NumFork;
-
-	if (TRUE == libutils_access_mode (XCFA_TMP_FIFO)) return;
-
-	args [ pos++ ] = "mkfifo";
-	args [ pos++ ] = XCFA_TMP_FIFO;
-	args [ pos++ ] = NULL;
-	args [ pos++ ] = NULL;
-
-	if ((NumFork = fork ()) == 0) {
-		execvp (args[0], args);
-		exit (2);
-	}
-
-	waitpid (NumFork, &status, WUNTRACED);
-}
-*/
 // 
 // 
 void mplayer_remove_fifo (void)
@@ -196,32 +175,6 @@ void mplayer_remove_fifo (void)
 	if (FALSE == libutils_access_mode (XCFA_TMP_FIFO)) return;
 	g_unlink (XCFA_TMP_FIFO);
 }
-/*
-void OLD_mplayer_remove_fifo (void)
-{
-	gchar *args[ 10 ];
-	gint   pos = 0;
-	gint   status;
-	pid_t  NumFork;		
-
-	if (FALSE == libutils_access_mode (XCFA_TMP_FIFO)) return;
-
-	args [ pos++ ] = "rm";
-	args [ pos++ ] = "-rf";
-	args [ pos++ ] = XCFA_TMP_FIFO;
-	args [ pos++ ] = NULL;
-	args [ pos++ ] = NULL;
-
-	if ((NumFork = fork ()) == 0) {
-		execvp (args[0], args);
-		exit (2);
-	}
-
-	waitpid (NumFork, &status, WUNTRACED);
-	
-	mplayer_remove_list_args ();
-}
-*/
 // FIFO COMMAND
 // 
 void mplayer_set_fifo (gchar *str)
@@ -375,22 +328,7 @@ static void mplayer_thread (void *arg)
 		buf [ pos +2 ] = '\0';
 		buf [ pos +3 ] = '\0';
 		
-		if (LIST_MPLAYER_FROM_SPLIT == VarMplayer.ListPlayFrom) {
-			// PRINT("LIST_MPLAYER_FROM_SPLIT");
-		
-			// TEST DE FIN DE LECTURE
-			// g_print("BUF =%s", buf);
-			Ptr = buf;
-			if (*Ptr == '\n') {
-				Ptr ++;
-				if (*Ptr == ':') {
-					BoolEndRead = TRUE;
-					VarMplayer.PercentTempsActuel =  99.855072;
-					break;
-				}
-			}
-		}
-		else if (LIST_MPLAYER_FROM_CD == VarMplayer.ListPlayFrom) {
+		if (LIST_MPLAYER_FROM_CD == VarMplayer.ListPlayFrom) {
 			// PRINT("LIST_MPLAYER_FROM_CD");
 		}
 		else if (LIST_MPLAYER_FROM_DVD == VarMplayer.ListPlayFrom) {
@@ -445,18 +383,7 @@ static void mplayer_thread (void *arg)
 			SecondesTempsActuel = (gdouble)Sec + ((gdouble)Hundr / 10.0);
 			VarMplayer.PercentTempsActuel = (SecondesTempsActuel / VarMplayer.DOUBLE_TempsTotal) * 100.0;
 						
-			if (VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_SPLIT) {
-				// g_print("SecondesTempsActuel                = %f\n", SecondesTempsActuel);
-				// g_print("VarMplayer.PercentTempsActuel       = %f\n", VarMplayer.PercentTempsActuel);
-				// g_print("VarMplayer.DOUBLE_TempsTotalSection  = %f\n", VarMplayer.DOUBLE_TempsTotalSection);
-				// g_print("VarMplayer.DOUBLE_TempsTotal          = %f\n", VarMplayer.DOUBLE_TempsTotal);
-				if (SecondesTempsActuel >= VarMplayer.DOUBLE_TempsTotalSection /*|| VarMplayer.PercentTempsActuel >=  99.855072*/) { 
-					VarMplayer.PercentTempsActuel =  99.855072;
-					BoolEndRead = TRUE;
-					break;
-				}
-			}
-			else if (VarMplayer.ListPlayFrom != LIST_MPLAYER_FROM_DVD) {
+			if (VarMplayer.ListPlayFrom != LIST_MPLAYER_FROM_DVD) {
 				if (VarMplayer.PercentTempsActuel >=  99.855072) {
 					BoolEndRead = TRUE;
 					break;
@@ -486,7 +413,7 @@ static void mplayer_thread (void *arg)
 
 	close(fd);
 	
-	if (TRUE == BoolEndRead /*&& VarMplayer.ListPlayFrom == LIST_MPLAYER_FROM_SPLIT*/) {
+	if (TRUE == BoolEndRead ) {
 		mplayer_set_fifo ("quit");
 	}
 	BoolEndRead = TRUE;
@@ -527,7 +454,6 @@ static gint mplayer_timeout (gpointer data)
 
 		switch (VarMplayer.ListPlayFrom) {
 		case LIST_MPLAYER_FROM_NONE :
-		case LIST_MPLAYER_FROM_FILE :
 			break;
 		
 		case  LIST_MPLAYER_FROM_DVD :
@@ -540,23 +466,15 @@ static gint mplayer_timeout (gpointer data)
 			else	mplayer_fifo_get_time_pos ();
 			if (NULL != VarMplayer.FuncSetValueTime && VarMplayer.PercentTempsActuel > 0.0) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
 			break;
-			
-		case  LIST_MPLAYER_FROM_SPLIT :
-			if (VarMplayer.DOUBLE_TempsTotal == 0.0)
-				mplayer_fifo_get_time_length ();
-			else	mplayer_fifo_get_time_pos ();
-			if (NULL != VarMplayer.FuncSetValueTime && VarMplayer.PercentTempsActuel > 0.0) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
-			break;
 		}
 	}
 	else if (VarMplayer.BoolThreadActivate == FALSE) {
 		
 		gtk_timeout_remove (VarMplayer.HandlerTimeout);
 
-		/* Widget de l'onglet dvd, cd ou fichiers sur ATTENTE */
+		// Widget de l'onglet dvd, cd ou fichiers sur ATTENTE
 		switch (VarMplayer.ListPlayFrom) {
 		case LIST_MPLAYER_FROM_NONE :
-		case LIST_MPLAYER_FROM_FILE :
 			break;
 		case LIST_MPLAYER_FROM_DVD :
 			VarMplayer.PercentTempsActuel = 0.0;
@@ -569,11 +487,6 @@ static gint mplayer_timeout (gpointer data)
 			if (VarMplayer.FuncSetValueTime) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
 			if (VarMplayer.FuncIconeStop) (*VarMplayer.FuncIconeStop) ();
 			break;
-		case LIST_MPLAYER_FROM_SPLIT :
-			// VarMplayer.PercentTempsActuel = 0.0;
-			if (VarMplayer.FuncSetValueTime) (*VarMplayer.FuncSetValueTime) (VarMplayer.PercentTempsActuel);
-			if (VarMplayer.FuncIconeStop) (*VarMplayer.FuncIconeStop) ();
-			break;
 		}
 		
 		VarMplayer.ListPlayFrom   = LIST_MPLAYER_FROM_NONE;
@@ -585,6 +498,7 @@ static gint mplayer_timeout (gpointer data)
 	}
 	return (TRUE);
 }
+// 
 // MPLAYER INIT
 // 
 void mplayer_init (
@@ -618,6 +532,7 @@ void mplayer_init (
 	VarMplayer.FuncIconeStop = p_FuncIconeStop;			// ***
 	VarMplayer.Func_request_stop = p_Func_request_stop;		// ***
 }
+// 
 // EXTERNAL CALL
 // 
 void mplayer_set_list (GList *p_list)
@@ -684,7 +599,6 @@ void mplayer_set_list (GList *p_list)
 	
 	// ACTIVATE THREAD
 	if (FALSE == VarMplayer.BoolThreadActivate) {
-		// VarMplayer.BoolThreadActivate = TRUE;
 		pthread_create (&VarMplayer.NmrTid, NULL ,(void *)mplayer_thread, (void *)NULL);
 	}
 	
