@@ -25,7 +25,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -45,9 +45,9 @@
 #endif
 
 #include "global.h"
-#include "configuser.h"
 #include "prg_init.h"
-#include "win_info.h"
+#include "configuser.h"
+#include "play_file.h"
 #include "notify_send.h"
 
 
@@ -88,21 +88,31 @@ static void NotifySend_thread (void *arg)
 // 
 void NotifySend_remove (void)
 {
-	if (NotifySend.Title != NULL) {
-		g_free (NotifySend.Title);
+	if( NotifySend.Title != NULL ) {
+		g_free( NotifySend.Title );
 		NotifySend.Title = NULL;
 	}
-	if (NotifySend.Str != NULL) {
-		g_free (NotifySend.Str);
+	if( NotifySend.Str != NULL ) {
+		g_free( NotifySend.Str );
 		NotifySend.Str = NULL;
 	}
 }
 // 
 // 
-void NotifySend_msg (gchar *Title, gchar *Str)
+void NotifySend_msg( gchar *Title, gchar *Str, gboolean p_BoolStopByUser )
 {
-	NotifySend_remove ();
+	// EN FIN DE CONVERSION:
+	// 	#include "play_file.h"
+	// 	void PlayFile_play (gchar *PathNameFile)
+	// 
+	if( TRUE == Config.BoolCheckbuttonEndOfConvert && FALSE == p_BoolStopByUser ) {
+		gchar	*PathNameFileMusic = g_strdup_printf( "%s/%s", Config.PathMusicFileEndOfConvert, Config.FileMusicFileEndOfConvert );
+		PlayFile_play( PathNameFileMusic );
+		g_free( PathNameFileMusic );
+		PathNameFileMusic = NULL;
+	}
 	
+	NotifySend_remove ();
 	if (FALSE == PrgInit.bool_notify_send) {
 		// SUPPRESSION DE L'ALERTE INDIQUANT L'ABSENCE DU PAQUET: LIBNOTIFY-BIN
 		// wininfo_create (
@@ -111,10 +121,10 @@ void NotifySend_msg (gchar *Title, gchar *Str)
 		//   	"");
 		return;
 	}
-	
 	NotifySend.Title = g_strdup_printf ("%s", Title);
 	NotifySend.Str   = g_strdup_printf ("%s", Str);
 	pthread_create (&NotifySend.nmr_tid, NULL ,(void *)NotifySend_thread, (void *)NULL);
+
 }
 
 
