@@ -28,8 +28,8 @@
 #ifndef notify_send_h
 #define notify_send_h 1
 
-void NotifySend_msg (gchar *Title, gchar *Str);
-void NotifySend_remove (void);
+void	NotifySend_msg( gchar *Title, gchar *Str, gboolean p_BoolStopByUser );
+void	NotifySend_remove (void);
 
 #endif
 
