@@ -172,17 +172,18 @@ void Parse_debug_print_cd (PARSE_TYPE p_ParseType)
 // 
 // SUPRESSION DES STRUCTURES ET DES GLIST
 //
-void Parse_remove (PARSE_TYPE p_ParseType)
+void Parse_remove( PARSE_TYPE p_ParseType, gboolean b_see )
 {
-	GList	*list = NULL;
-	PARSE	*Parse = NULL;
+	GList		*list = NULL;
+	PARSE		*Parse = NULL;
+	gboolean	BoolDestroy = FALSE;
 
 	if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
 		list = g_list_first (VarParse.ListParseStockCd);
 	} else if( p_ParseType == PARSE_TYPE_TITLE_CD ) {
 		list = g_list_first (VarParse.ListParseTitleCd);
 	}
-	while(  list ) {
+	while( list ) {
 		if( (Parse = (PARSE *)list->data) != NULL ) {
 			switch (Parse->CdTypeTag ) {
 			case CD_TAG_INT_NUMBER :
@@ -216,6 +217,8 @@ void Parse_remove (PARSE_TYPE p_ParseType)
 			g_free (Parse);
 			Parse = NULL;
 			list->data = NULL;
+			
+			BoolDestroy = TRUE;
 		}
 		list = g_list_next (list);
 	}
@@ -227,6 +230,10 @@ void Parse_remove (PARSE_TYPE p_ParseType)
 		g_list_free (VarParse.ListParseTitleCd);
 		VarParse.ListParseTitleCd = NULL;
 	}
+	
+	if( TRUE == b_see && TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print( "\tRemove struct PARSE: ok\n" );
+	
 }
 // 
 // ALLOCATION ET STOCKAGE DE TOUS LES TYPES SAUF: CD_TAG_CAR_REPLACE
@@ -339,7 +346,7 @@ void Parse_entry (PARSE_TYPE p_ParseType)
 	}
 	
 	// REMOVE LISTE
-	Parse_remove (p_ParseType);
+	Parse_remove (p_ParseType, FALSE);
 	
 	// PARSE
 	while(  PtrTemplate && *PtrTemplate != '\0' ) {
@@ -759,9 +766,11 @@ gchar *Parse_get_line (PARSE_TYPE p_ParseType, gint p_Num_cell)
 		}
 		
 		// ERRADICATION DE SLASH
+		// DEUX CARACTERES SLASH ( // ) NE PEUVENT ETRE COTE A COTE
 		Ptr = gstr->str;
 		while(  *Ptr ) {
-			if( '/' == *Ptr) *Ptr = '-';
+			// if( '/' == *Ptr) *Ptr = '-';
+			if( '/' == *Ptr && '/' == *(Ptr +1) ) *Ptr = '-';
 			Ptr ++;
 		}
 	}
