@@ -34,10 +34,10 @@ typedef enum {
 	PARSE_TYPE_TITLE_CD
 } PARSE_TYPE;
 
-void Parse_entry (PARSE_TYPE p_ParseType);
-void Parse_remove (PARSE_TYPE p_ParseType);
-void Parse_print_cd (PARSE_TYPE p_ParseType);
-gchar *Parse_get_line (PARSE_TYPE p_ParseType, gint p_Num_cell);
+void	Parse_entry( PARSE_TYPE p_ParseType );
+void	Parse_remove( PARSE_TYPE p_ParseType, gboolean b_see );
+void	Parse_print_cd( PARSE_TYPE p_ParseType );
+gchar	*Parse_get_line( PARSE_TYPE p_ParseType, gint p_Num_cell );
 
 
 #endif
