@@ -166,7 +166,8 @@ void poche_remove_ListImage( void )
 	}
 	g_list_free( view.ListImage );
 	view.ListImage = NULL;
-	g_print( "\tRemove = %d\n", NbrFree );
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print( "\tRemove: %d\n", NbrFree );
 }
 // 
 // 
