@@ -149,7 +149,6 @@ void pochedir_remove_GlistPochette( void )
 void pochedir_make_glist (gchar *filename)
 {
 	GLIST_POCHETTE	*new = NULL;
-	// guint		num = 0;
 	
 	// Allocation memoire
 	if( NULL == ( new = ( GLIST_POCHETTE * )g_malloc0( sizeof(GLIST_POCHETTE)))) {
@@ -157,27 +156,10 @@ void pochedir_make_glist (gchar *filename)
 		g_print ("\tERREUR D'ALLOCATION\n");
 		return;
 	}
-
-	new->name_img = g_strdup (filename);
+	// init
+	new->name_img         = g_strdup (filename);
 	new->BoolStructRemove = FALSE;
 	
-	/*
-	// Numero de l'image.png
-	num = 1;
-	// Trouver un nom de fichier libre
-	while (TRUE) {
-		new->name_png = g_strdup_printf ("%s/%03d.png", poche.Path_pochette_png, num);
-		if (FALSE == libutils_test_file_exist (new->name_png)) break;
-		num ++;
-		g_free (new->name_png);
-		new->name_png = NULL;
-	}
-
-	// Construction du fichier PNG
-	pocheexec_convert_to_png (filename, new->name_png, "80x80");
-	*/
-
-
 	// Stocke
 	view.glist = g_list_append (view.glist, new);
 }
