@@ -93,39 +93,15 @@ POCHEWEB_EVENT pocheweb_event;
 */
 gchar *pocheweb_get_on_web_file_img (gchar *filename)
 {
-	/*FILE     *index;*/
 	gchar    *name_file = NULL;
-	/*gchar    *ptr_name = NULL;*/
-	gint      num = 0;
+	gint      num;
 	gchar    *LineCommand = NULL;
 	gint	  Dummy;
 
 
-	// PRINT_FUNC_LF();
+	PRINT_FUNC_LF();
 
-	/* Si le nom existe deja, en chercher un nouveau */
-	/*
-	if ( (ptr_name = strrchr (filename, '/')) == NULL) return (NULL);
-	ptr_name ++;
-	name_file = g_strdup_printf ("%s/%s", Config.PathPochette, ptr_name);
-	if (libutils_test_file_exist (name_file) == TRUE) {
-		g_print ("EXISTE DEJA: %s\n", name_file);
-		g_free(name_file);
-		name_file = NULL;
-
-		num = 1;
-		while (TRUE) {
-			name_file = g_strdup_printf ("%s/%03d.jpg", Config.PathPochette, num);
-			if (libutils_test_file_exist (name_file) == FALSE) {
-				g_print ("NOUVEAU NOM: %s\n", name_file);
-				break;
-			}
-			num ++;
-			g_free (name_file);
-			name_file = NULL;
-		}
-	}
-	*/
+	// NEW NAME IF IMAGE EXIST
 	num = 1;
 	while (TRUE) {
 		name_file = g_strdup_printf ("%s/%03d.jpg", Config.PathPochette, num);
@@ -138,55 +114,58 @@ gchar *pocheweb_get_on_web_file_img (gchar *filename)
 		name_file = NULL;
 	}
 	
+	// IMAGE IMPORT
 	LineCommand = g_strdup_printf ("wget --user-agent=\"Mozilla 22.0\" -O %s %s", name_file, filename);
-
-// g_print( "LINECOMMAND=\n%s\n", LineCommand );
-// g_print( "name_file = %s\n", name_file );
-// g_print( "filename = %s\n", filename );
-
-
 	Dummy = system (LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
-
+	
+	// L'IMPORT EST IL CORRECT ?
 	if (libutils_test_file_exist (name_file) == FALSE) {
 		g_free(name_file);
 		name_file = NULL;
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print( " ******************************BAD IMPORT ******************************\n");
 	}
-	if( FALSE == FileIs_image( name_file )) {
-		g_unlink (name_file);
-		g_free (name_file);
-		name_file = NULL;
+	
+	// IMAGE FILE ?
+	if( NULL != name_file ) {
+		if( FALSE == FileIs_image( name_file )) {
+			g_unlink (name_file);
+			g_free (name_file);
+			name_file = NULL;
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print( " ******************************BAD IMAGE ******************************\n");
+		}
 	}
 
 	return ((gchar *)name_file);
 }
 
-/* Le fichier NAME_INDEX_HTML est analyse:
-*  Tous les noms de fichiers seront passes en parametre a: pocheget_get_file (char *filename, int cpt)
-*  pour recuperation et seront sauvegardes
-*/
+// Le fichier NAME_INDEX_HTML est analyse:
+// Tous les noms de fichiers seront passes en parametre a: pocheget_get_file (char *filename, int cpt)
+// pour recuperation et seront sauvegardes
+// 
 void pocheweb_analyze_file_html (void)
 {
-	size_t   cpt = 1;
-	size_t   i;
-	size_t   lenfile = 0;
-	gchar   *buffer = NULL;
-	gchar   *result = g_malloc0 (sizeof (char) * (BUFFER_SIZE + 10));
+	size_t	lenfile = 0;
+	gchar	*buffer = NULL;
+	gchar   *result = NULL;
 	FILE    *fp;
-	gchar   *ptr = NULL;
-	gchar   *ptr1 = NULL;
-	gchar   *ptr_name = NULL;
-	gint     TypeCode = 0;
-	size_t	 Dummy;
+	gchar   *PtrBegin = NULL;
+	gchar   *PtrEnd = NULL;
+	gchar   *PtrName = NULL;
+	size_t	Dummy;
+	gint	NumFile = 1;
 	
-	// PRINT_FUNC_LF();
+	PRINT_FUNC_LF();
 
 	pocheweb_event.name_index_html = g_strdup_printf ("%s/index.html", Config.PathPochette);
 
 	lenfile = libutils_get_size_file (pocheweb_event.name_index_html);
 	if (lenfile <= 100) {
-		g_print ("ERREUR TAILLE DE %s = %d\n", pocheweb_event.name_index_html, (gint)lenfile);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("ERREUR TAILLE DE %s = %d\n", pocheweb_event.name_index_html, (gint)lenfile);
 		g_free (pocheweb_event.name_index_html);
 		pocheweb_event.name_index_html = NULL;
 		return;
@@ -197,84 +176,74 @@ void pocheweb_analyze_file_html (void)
 	Dummy = fread (buffer, 1, lenfile, fp);
 	fclose (fp);
 
-	ptr = buffer;
-	while (*ptr) ptr ++;
-
-	if (strstr (buffer, "/images?q=tbn:")) {
-		TypeCode = 0;
-		g_print ("\n");
-		PRINT_FUNC_LF();
-		g_print ("\tRecup des infos web via: \"/images?q=tbn:\"\n");
-		g_print ("\n");
-	} else if (strstr (buffer, "M:\",\"http")) {
-		TypeCode = 1;
-		g_print ("\n");
-		PRINT_FUNC_LF();
-		g_print ("\tRecup des infos web via: \"M:\",\"http\"\n");
-		g_print ("\n");
-	} else {
-		PRINT_FUNC_LF();
-		g_free (buffer);
-		buffer = NULL;
-		g_free (result);
-		result = NULL;
-		g_unlink (pocheweb_event.name_index_html);
-		g_free (pocheweb_event.name_index_html);
-		pocheweb_event.name_index_html = NULL;
-		
-		return;
-	}
-	
-	ptr = buffer;
-	while ((ptr - buffer) < lenfile) {
-		/*if ((ptr = strstr (ptr + 1, "/images?q=tbn:"))) {*/
-		/*if ((ptr = strstr (ptr + 1, "M:\",\"http"))) {*/
-		
-		if ((ptr = strstr (ptr + 1, TypeCode == 0 ? "/images?q=tbn:" : "M:\",\"http"))) {
-		
-			if ((ptr = strstr (ptr, "http:"))) {
-				for (i=0; i < BUFFER_SIZE; i++) result [ i ] = '\0';
-				ptr1 = ptr;
+	// 
+	// RECHERCHE D'UNE SEQUENCE:
+	//	.jpg
+	// ... PRECEDEE D'UNE SEQUENCE:
+	//	http://
+	// 
+	PtrEnd = buffer;
+	// BOUCLE
+	while( (PtrEnd - buffer) < lenfile ) {
+		// SEARCH END STRING '.jpg'
+		if( NULL != ( PtrEnd = strstr( PtrEnd, ".jpg" ))) {
+			PtrBegin = PtrEnd;
+			PtrBegin --;
+			PtrEnd += 4;
+			// SEARCH BEGIN STRING 'http:'
+			while( PtrBegin > buffer ) {
 				
-				if (TypeCode == 0) {
-					while (*ptr1 != ' ') ptr1 ++;
-				}
-				else if (TypeCode == 1) {
-					while (*ptr1 != '\"') ptr1 ++;
-				}
-				strncpy (result, ptr, ptr1 - ptr);
-				
-				// VIRER LE '"' de fin de chaine
-				for (ptr1 = result; ptr1 && *ptr1; ptr1 ++)
-					if (*ptr1 == '"') {
-						*ptr1 = '\0';
-						break;
+				if( *(PtrBegin + 0) == 'h' &&
+				    *(PtrBegin + 1) == 't' &&
+				    *(PtrBegin + 2) == 't' &&
+				    *(PtrBegin + 3) == 'p' &&
+				    *(PtrBegin + 4) == ':' ) {
+					
+					// MAKE STRING
+					result = g_strnfill( (PtrEnd - PtrBegin) + 10, '\0' );
+					// GET STRING
+					strncpy( result, PtrBegin, PtrEnd - PtrBegin );
+					
+					if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+						g_print( "NumFile = %d\n", NumFile );
+						g_print( "result = %s\n", result );
 					}
-				
-				if ((ptr_name = pocheweb_get_on_web_file_img (result))) {
-					if (pocheweb_event.name) {
-						g_free (pocheweb_event.name);
-						pocheweb_event.name = NULL;
+					NumFile ++;
+					
+					if ((PtrName = pocheweb_get_on_web_file_img (result))) {
+						if (pocheweb_event.name) {
+							g_free (pocheweb_event.name);
+							pocheweb_event.name = NULL;
+						}
+						pocheweb_event.name = g_strdup( PtrName );
+						pochedir_make_glist( PtrName );
+						
+						g_free( PtrName );
+						PtrName = NULL;
 					}
-					pocheweb_event.name = g_strdup (ptr_name);
-					pochedir_make_glist (ptr_name);
-				}
-
-				if (WindScan_close_request ()) {
-					g_print ("DEMANDE D'ANNULATION DEPUIS: ");
-					PRINT_FUNC_LF();
+					g_free( result );
+					result = NULL;
 					break;
 				}
-
-				cpt ++;
+				else {
+					PtrBegin --;
+				}
+			}
+			
+			if (WindScan_close_request ()) {
+				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+					g_print ("DEMANDE D'ANNULATION DEPUIS: ");
+					PRINT_FUNC_LF();
+				}
+				break;
 			}
 		}
-		if ((ptr - buffer) >= lenfile -100) break;
+		PtrEnd ++;
+		if ((PtrEnd - buffer) >= lenfile -100) break;
 	}
+
 	g_free (buffer);
 	buffer = NULL;
-	g_free (result);
-	result = NULL;
 	g_unlink (pocheweb_event.name_index_html);
 	g_free (pocheweb_event.name_index_html);
 	pocheweb_event.name_index_html = NULL;
@@ -298,7 +267,8 @@ gboolean pocheweb_recup_file_html (gchar *cd_name)
 	/* Construction du path	*/
 	Ptr = PtrNew = g_strdup_printf ("http://images.google.com/images?q=%s", cd_name);
 	/* Chaine de transformation du nom */
-	ptrname = name = g_strnfill (1024, '\0');
+	name = g_strnfill (2048, '\0');
+	ptrname = name;
 /*
 http://images.google.com/images?q=Dire   Straits   Brothers   In   Arms+Dire   Straits   Brothers   in   arms
 http://images.google.com/images?q=Dire%20Straits%20Brothers%20In%20Arms+Dire%20Straits%20Brothers%20in%20arms
@@ -323,13 +293,20 @@ http://images.google.com/images?q=Dire%20Straits%20Brothers%20In%20Arms+Dire%20S
 
 	pocheweb_event.name_index_html = g_strdup_printf ("%s/index.html", Config.PathPochette);
 	LineCommand = g_strdup_printf ("wget --user-agent=\"Mozilla 22.0\" -O %s %s", pocheweb_event.name_index_html, name);
-g_print("LineCommand=%s\n", LineCommand);
+	
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print( "pocheweb_event.name_index_html = %s\n", pocheweb_event.name_index_html );	// /tmp/XcfaPochette/index.html
+		g_print( "name                           = %s\n", name );				// http://images.google.com/images?q=
+		g_print( "LineCommand=%s\n", LineCommand );	// wget --user-agent="Mozilla 22.0" -O /tmp/XcfaPochette/index.html http://images.google.com/images?q=
+	}
 	Dummy = system (LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
 
 	bool_ret = (libutils_test_file_exist (pocheweb_event.name_index_html) && libutils_get_size_file (pocheweb_event.name_index_html) > 0);
-
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print( "bool_ret = %s\n", TRUE == bool_ret ? "TRUE" : "FALSE" );
+	}
 	g_free (name);
 	name = NULL;
 
