@@ -1250,5 +1250,83 @@ void popup_viewport( GLIST_POCHETTE *gl )
 	
 	gtk_menu_popup( GTK_MENU( Menu), NULL, NULL, NULL, NULL, 3, 0 );
 }
+// 
+//
+// POPUP TAG CD
+// 
+// 
+/*
+typedef struct {
+	gboolean	BoolFromPopup;
+	gint		num;
+	gchar		*name;
+} CD_POPUP_GENRE;
+*/
+CD_POPUP_GENRE CdPopupGenre = { FALSE, -1, NULL };
+
+void on_menu_popup_num_activate( GtkMenuItem *menuitem, gpointer user_data )
+{
+	gint	Choice = GPOINTER_TO_INT(user_data);
+	
+	CdPopupGenre.num           = Choice;
+	CdPopupGenre.BoolFromPopup = TRUE;
+	
+	PRINT_FUNC_LF();
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print( "\tPtrEntry = %s\n", CdPopupGenre.name );
+		g_print( "\tNumEntry = %d\n", Choice);
+	}
+
+	gtk_entry_set_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre")), CdPopupGenre.name );
+	cd_expander_set_genre( CdPopupGenre.num, CdPopupGenre.name );
+	
+	CdPopupGenre.BoolFromPopup = FALSE;
+}
+void on_menu_popup_txt_activate( GtkMenuItem *menuitem, gpointer user_data )
+{
+	gchar	*Ptr = (gchar *)user_data;
+	
+	if( NULL != CdPopupGenre.name ) {
+		g_free( CdPopupGenre.name );
+		CdPopupGenre.name = NULL;
+	}
+	CdPopupGenre.name = g_strdup( Ptr );
+}
+void popup_menu_cd( void )
+{
+	GtkWidget	*Menu;
+	GtkWidget	*RemoveImage;
+	gint		Choice;
+	
+	Menu = gtk_menu_new(  );
+	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	for( Choice = 0; -1 != StructTagsFileMp3[ Choice ].num; Choice ++ ) {
+		
+		// StructTagsFileMp3[ i ].name
+		// StructTagsFileMp3[ i ].num
+		
+		RemoveImage = gtk_menu_item_new_with_mnemonic( StructTagsFileMp3[ Choice ].name );
+		
+		gtk_widget_show( RemoveImage );
+		gtk_container_add( GTK_CONTAINER( Menu), RemoveImage );
+		
+		g_signal_connect(( gpointer) RemoveImage, "activate", G_CALLBACK(on_menu_popup_txt_activate), (gpointer)StructTagsFileMp3[ Choice ].name );
+		g_signal_connect(( gpointer) RemoveImage, "activate", G_CALLBACK(on_menu_popup_num_activate), GINT_TO_POINTER(StructTagsFileMp3[ Choice ].num));
+		
+		GLADE_HOOKUP_OBJECT( Menu, RemoveImage, "RemoveImage" );
+	}
+	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu, "Menu" );
+
+	gtk_menu_popup( GTK_MENU( Menu), NULL, NULL, NULL, NULL, 3, 0 );
+}
+
+
+
+
+
+
+
+
 
 
