@@ -49,6 +49,15 @@ void	popup_trash (void);
 void	popup_normalise_cd (void);
 void	popup_normalise_dvd (void);
 
+typedef struct {
+	gboolean	BoolFromPopup;
+	gint		num;
+	gchar		*name;
+} CD_POPUP_GENRE;
+extern CD_POPUP_GENRE CdPopupGenre ;
+
+void	popup_menu_cd( void );
+
 
 #endif
 
