@@ -491,17 +491,19 @@ void prginit_affiche_glist (void)
 // 
 // 
 void prginit_print_info (void)
-{
-	gint	index;
-	
+{	
 	PRINT_FUNC_LF();
 	
-	g_print ("!------------------------------\n");
-	g_print ("! INSTALL      NAME\n");
-	g_print ("!------------------------------\n");
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++)
-		g_print("!  %s   %s\n", (*TableauPrgExtern [ index ] . BoolFound == TRUE) ? "Yes      " : " NO  --> ", TableauPrgExtern [ index ] . PtrName);
-	g_print ("!------------------------------\n\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		gint	index;
+		
+		g_print ("!------------------------------\n");
+		g_print ("! INSTALL      NAME\n");
+		g_print ("!------------------------------\n");
+		for (index = 0; index < NMR_MAX_TABLEAU; index ++)
+			g_print("!  %s   %s\n", (*TableauPrgExtern [ index ] . BoolFound == TRUE) ? "Yes      " : " NO  --> ", TableauPrgExtern [ index ] . PtrName);
+		g_print ("!------------------------------\n\n");
+	}
 }
 // 
 // 
@@ -682,8 +684,8 @@ void on_scrolledwindow_applications_externes_realize (GtkWidget *widget, gpointe
 	GtkWidget    *treeview;
 	GtkListStore *store;
 
-	var_prgextern.Pixbuf_Ok        = libutils_init_pixbufs ("xcfa/prg-ok.png");
-	var_prgextern.Pixbuf_Not_Ok    = libutils_init_pixbufs ("xcfa/dbfs-no.png");
+	var_prgextern.Pixbuf_Ok        = libutils_init_pixbufs ("prg-ok.png");
+	var_prgextern.Pixbuf_Not_Ok    = libutils_init_pixbufs ("dbfs-no.png");
 
 	var_prgextern.Adr_scroll = widget;
 	var_prgextern.Adr_List_Store =
