@@ -28,9 +28,14 @@
 #ifndef replaygain_h
 #define replaygain_h 1
 
-typedef enum {_CLEAR_REPLAYGAIN_ = 0, _APPLY_REPLAYGAIN_} TYPE_REPLAYGAIN;
 
-void replaygain_action (TYPE_REPLAYGAIN type_replaygain);
+typedef enum {
+	_CLEAR_REPLAYGAIN_ = 0,		// 
+	_APPLY_REPLAYGAIN_		// 
+} TYPE_REPLAYGAIN;
+
+void	replaygain_action (TYPE_REPLAYGAIN type_replaygain);
+
 
 #endif
 
