@@ -199,7 +199,8 @@ void scan_set_sel_reader_cd (gint column, gint row)
 void scan_print_name_cdrom (gchar *NameDevice, gchar *NameLink)
 {
 	/* PRINT_FUNC_LF(); */
-	g_print ("\tNameDevice=%s  NameLink=%s\n", NameDevice, NameLink);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\tNameDevice=%s  NameLink=%s\n", NameDevice, NameLink);
 }
 
 
@@ -227,7 +228,8 @@ void scan_remove_glist_media (void)
 	}
 	g_list_free (var_scancd.Media_List);
 	var_scancd.Media_List = NULL;
-	g_print ("\tRemove: %d\n", NbList);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\tRemove: %d\n", NbList);
 }
 
 // 
@@ -281,7 +283,8 @@ GList *scan_scan_drives_cd_dvd (void)
 		cd_list = g_list_first (List);
 		while (cd_list) {
 			if ((gchar *)cd_list->data) {
-				g_print ("%s\n", (gchar *)cd_list->data);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("%s\n", (gchar *)cd_list->data);
 				for (Lcurentry = listesearchdrives; Lcurentry->detectline; Lcurentry++) {
 					/*Lcurentry->tst = FALSE;*/
 					if (0 == strncmp((gchar *)cd_list->data, Lcurentry->info, strlen((gchar *)cd_list->data))) {
@@ -304,8 +307,10 @@ GList *scan_scan_drives_cd_dvd (void)
 
 	/* l'analyse des medias commence ici */
 	var_scancd.TotalReadersDetected = 0;
-	g_print ("\nAnalyse devices in : ");
-	g_print ("%s::%s(line=%d) \n", __FILE__, __FUNCTION__, __LINE__);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("\nAnalyse devices in : ");
+		g_print ("%s::%s(line=%d) \n", __FILE__, __FUNCTION__, __LINE__);
+	}
 	for (pass = 0, Lcurentry = listesearchdrives; Lcurentry->detectline; pass++, Lcurentry++) {
 
 		/* Entree en test ? */
@@ -361,9 +366,10 @@ GList *scan_scan_drives_cd_dvd (void)
 						}
 						Ptr ++;
 					}
-					g_print ("\tline[ %d ] %s   ", pass, Lcurentry->tp == IDE ? "IDE" : "SCSI");
-					g_print ("%s\t'%s'\n", Lcurentry->useline, str);
-
+					if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+						g_print ("\tline[ %d ] %s   ", pass, Lcurentry->tp == IDE ? "IDE" : "SCSI");
+						g_print ("%s\t'%s'\n", Lcurentry->useline, str);
+					}
 					if ((Media = (MEDIA *)g_malloc0 (sizeof (MEDIA)))) {
 						Media->Full_Name = g_strdup (str);
 						Media->Device    = g_strdup (Lcurentry->useline);
@@ -378,7 +384,8 @@ GList *scan_scan_drives_cd_dvd (void)
 				}
 				else {
 					PRINT_FUNC_LF();
-					g_print ("La ligne renvoyee par: dvd+rw-mediainfo est inconnue\n");
+					if( TRUE == OptionsCommandLine.BoolVerboseMode )
+						g_print ("La ligne renvoyee par: dvd+rw-mediainfo est inconnue\n");
 				}
 			}
 		}
