@@ -39,9 +39,10 @@ typedef struct {
 
 } MEDIA;
 
-extern GList *Media_List;
-
-typedef enum { _CD_, _DVD_ } TYPE_READER;
+typedef enum {
+	_CD_ = 0,		// 
+	_DVD_			// 
+} TYPE_READER;
 
 void		scan_remove_glist_media (void);
 void		scan_open_peri_cd (void);
