@@ -318,12 +318,14 @@ static gint VarSplit_timeout (gpointer data)
 		// 
 		split_set_name_file ();
 
-		g_print("\ttime     : Temps d'ecoute             = %s\n", VarSplit.Tags->time);
-		g_print("\tSecTime  : Temps d'ecoute en secondes = %d\n", VarSplit.Tags->SecTime);
-		g_print("\thertz    : Taux d'échantillonnage     = %s\n", VarSplit.Tags->hertz);
-		g_print("\tvoie     : 1, 2, 4, 6                 = %s\n", VarSplit.Tags->voie);
-		g_print("\tbits     : 8, 16, 24, 32 ou 64        = %s\n", VarSplit.Tags->bits);
-		g_print("\n");
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print("\ttime     : Temps d'ecoute             = %s\n", VarSplit.Tags->time);
+			g_print("\tSecTime  : Temps d'ecoute en secondes = %d\n", VarSplit.Tags->SecTime);
+			g_print("\thertz    : Taux d'échantillonnage     = %s\n", VarSplit.Tags->hertz);
+			g_print("\tvoie     : 1, 2, 4, 6                 = %s\n", VarSplit.Tags->voie);
+			g_print("\tbits     : 8, 16, 24, 32 ou 64        = %s\n", VarSplit.Tags->bits);
+			g_print("\n");
+		}
 		
 		for (IndicePoints = 0; IndicePoints < MAX_SELECTEURS_SPLIT; IndicePoints ++) {
 			if (-1 != VarSplit.Selecteur [ IndicePoints ] . Nmr) {
@@ -552,7 +554,8 @@ void split_load_from_dnd (GSList *p_list)
 	
 	while (NULL != gs_List) {
 		if (NULL != (Ptr = (gchar *)gs_List->data)) {
-			g_print("\t%s\n", Ptr);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print("\t%s\n", Ptr);
 			TypeFileIs = GetInfo_file_is (Ptr);
 			if (FILE_IS_WAV == TypeFileIs ||
 			    FILE_IS_FLAC == TypeFileIs ||
