@@ -296,7 +296,8 @@ static gint SplitConv_timeout (gpointer data)
 	}
 	else if (FALSE == conv.bool_thread_conv) {
 		PRINT("FIN TIMEOUT SPLITCONV");
-		g_print ("\n");
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("\n");
 		gtk_timeout_remove (conv.handler_timeout_conv);
 		// WindScan_close ();
 		while (gtk_events_pending()) gtk_main_iteration();
@@ -362,15 +363,19 @@ void SplitConv_to (gchar *p_PathNameFile)
 	if (FILE_IS_WAV == VarSplitConv.TypeFileIs) {
 		tagswav_file_GetBitrate (p_PathNameFile, &Channels, &Hertz, &Bits);
 		PRINT_FUNC_LF();
-		g_print ("\t%s\n", p_PathNameFile);
-		g_print ("\tChannels: %d,  Hertz: %d,   Bits: %d\n", Channels, Hertz, Bits);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print ("\t%s\n", p_PathNameFile);
+			g_print ("\tChannels: %d,  Hertz: %d,   Bits: %d\n", Channels, Hertz, Bits);
+		}
 		if (2 != Channels || 44100 != Hertz || 16 != Bits) {
-			g_print ("\tNOT OK !!!\n\n");
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("\tNOT OK !!!\n\n");
 			VarSplitConv.DestPathnameFile = g_strdup (SPLIT_FILE_TMP_WAV);
 			conv.total_convert = 2;
 		}
 		else {
-			g_print ("\tOK :-)\n\n");
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("\tOK :-)\n\n");
 			VarSplitConv.TypeFileIs = FILE_IS_NONE;
 		}
 	}
