@@ -56,20 +56,22 @@ extern VAR_SPLIT VarSplit;
 
 void DEBUG_PRINT_SplitSelector (void)
 {
-	gint	IndiceSrc;
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		gint	IndiceSrc;
 	
-	g_print ("\n");
-	for (IndiceSrc = 0; IndiceSrc < MAX_SELECTEURS_SPLIT; IndiceSrc ++) {
-		if (-1 != VarSplit.Selecteur [ IndiceSrc ] . Nmr) {
-			g_print ("[ %2d ]  Begin = %6d   End = %6d\t",
-					IndiceSrc,
-					(gint)VarSplit.Selecteur [ IndiceSrc ] . BeginPaint,
-					(gint)VarSplit.Selecteur [ IndiceSrc ] . EndPaint
-					);
-			g_print ("PercentBegin = %2.6f   PercentEnd = %2.6f\n",
-					VarSplit.Selecteur [ IndiceSrc ] . PercentBegin,
-					VarSplit.Selecteur [ IndiceSrc ] . PercentEnd
-					);
+		g_print ("\n");
+		for (IndiceSrc = 0; IndiceSrc < MAX_SELECTEURS_SPLIT; IndiceSrc ++) {
+			if (-1 != VarSplit.Selecteur [ IndiceSrc ] . Nmr) {
+				g_print ("[ %2d ]  Begin = %6d   End = %6d\t",
+						IndiceSrc,
+						(gint)VarSplit.Selecteur [ IndiceSrc ] . BeginPaint,
+						(gint)VarSplit.Selecteur [ IndiceSrc ] . EndPaint
+						);
+				g_print ("PercentBegin = %2.6f   PercentEnd = %2.6f\n",
+						VarSplit.Selecteur [ IndiceSrc ] . PercentBegin,
+						VarSplit.Selecteur [ IndiceSrc ] . PercentEnd
+						);
+			}
 		}
 	}
 }
@@ -246,25 +248,30 @@ void SplitSelector_add (gint p_CursorX)
 		if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 			for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > 0; IndiceDest --) {
 				IndiceSrc = IndiceDest -1;
-				g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 				g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 			}
 		}
 		
 		// VALIDER LA NOUVELLE SELECTION ACTIVE
 		VarSplit.SelecteurActif = 0;
-		g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
 		
 		// AJOUTER UN SELECTEUR
 		VarSplit.NbrSelecteurs ++;
-		g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
 		
 		// REINDEXER LA NUMEROTATION
 		for (IndiceSrc = 0; IndiceSrc < VarSplit.NbrSelecteurs; IndiceSrc ++) {
 			VarSplit.Selecteur [ IndiceSrc ] . Nmr = IndiceSrc;
-			g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 		}
-		g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 		
 		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint   = CursorX;
 		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
@@ -301,25 +308,30 @@ void SplitSelector_add (gint p_CursorX)
 		if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 			for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > VarSplit.NbrSelecteurs -1; IndiceDest --) {
 				IndiceSrc = IndiceDest -1;
-				g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 				g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 			}
 		}
 		
 		// VALIDER LA NOUVELLE SELECTION ACTIVE
 		VarSplit.SelecteurActif = VarSplit.NbrSelecteurs;
-		g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
 		
 		// AJOUTER UN SELECTEUR
 		VarSplit.NbrSelecteurs ++;
-		g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
 		
 		// REINDEXER LA NUMEROTATION
 		for (IndiceSrc = 0; IndiceSrc < VarSplit.NbrSelecteurs; IndiceSrc ++) {
 			VarSplit.Selecteur [ IndiceSrc ] . Nmr = IndiceSrc;
-			g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 		}
-		g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 		
 		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint   = CursorX;
 		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
@@ -360,25 +372,30 @@ void SplitSelector_add (gint p_CursorX)
 				if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 					for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > Cpt; IndiceDest --) {
 						IndiceSrc = IndiceDest -1;
-						g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 						g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 					}
 				}
 				
 				// VALIDER LA NOUVELLE SELECTION ACTIVE
 				VarSplit.SelecteurActif = Cpt +1;
-				g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
 				
 				// AJOUTER UN SELECTEUR
 				VarSplit.NbrSelecteurs ++;
-				g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
 				
 				// REINDEXER LA NUMEROTATION
 				for (IndiceSrc = 0; IndiceSrc < VarSplit.NbrSelecteurs; IndiceSrc ++) {
 					VarSplit.Selecteur [ IndiceSrc ] . Nmr = IndiceSrc;
-					g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+					if( TRUE == OptionsCommandLine.BoolVerboseMode )
+						g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 				}
-				g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 				
 				/*
 				RESLOLU @Dzef
@@ -431,25 +448,30 @@ void SplitSelector_add (gint p_CursorX)
 				if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 					for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > Cpt; IndiceDest --) {
 						IndiceSrc = IndiceDest -1;
-						g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 						g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 					}
 				}
 				
 				// VALIDER LA NOUVELLE SELECTION ACTIVE
 				VarSplit.SelecteurActif = Cpt +1;
-				g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("VarSplit.SelecteurActif = %d\n",VarSplit.SelecteurActif);
 				
 				// AJOUTER UN SELECTEUR
 				VarSplit.NbrSelecteurs ++;
-				g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("VarSplit.NbrSelecteurs = %d\n",VarSplit.NbrSelecteurs);
 				
 				// REINDEXER LA NUMEROTATION
 				for (IndiceSrc = 0; IndiceSrc < VarSplit.NbrSelecteurs; IndiceSrc ++) {
 					VarSplit.Selecteur [ IndiceSrc ] . Nmr = IndiceSrc;
-					g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+					if( TRUE == OptionsCommandLine.BoolVerboseMode )
+						g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 				}
-				g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 				
 				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint    = CursorX;
 				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
