@@ -562,7 +562,8 @@ void SplitSpectre_search_blank_pass (void)
 				if (PointBegin > -1 && PointEnd - PointBegin > 13) {
 					
 					IndicePoints ++;
-					g_print ("PointBegin = %6d   PointEnd = %6d   Diff = %6d\n", PointBegin, PointEnd, PointEnd - PointBegin);
+					if( TRUE == OptionsCommandLine.BoolVerboseMode )
+						g_print ("PointBegin = %6d   PointEnd = %6d   Diff = %6d\n", PointBegin, PointEnd, PointEnd - PointBegin);
 					
 					PercentBegin = ((gdouble)PointBegin / (gdouble)MaxPoints) * 100.0;
 					ValueBegin = ((gdouble)SplitSpectre_get_with() * (gdouble)PercentBegin) / 100.0;
@@ -592,9 +593,11 @@ void SplitSpectre_search_blank_pass (void)
 		VarSplit.Selecteur [ 0 ] . EndPaint   = ValueEnd;
 	}
 	
-	g_print ("\n");
-	g_print ("IndicePoints = [ 0 .. %d ]\n", IndicePoints);
-	g_print ("\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("\n");
+		g_print ("IndicePoints = [ 0 .. %d ]\n", IndicePoints);
+		g_print ("\n");
+	}
 	
 	// DEBUT
 	Indice = 0;
@@ -614,7 +617,8 @@ void SplitSpectre_search_blank_pass (void)
 				// break;
 			// }
 			if ((gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint >= (gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint) {
-				g_print ("[ %02d ]ERREUR entre Begin %d et End %d  -->  RECTIFICATION\n", IndicePoints, IndicePoints, IndicePoints);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("[ %02d ]ERREUR entre Begin %d et End %d  -->  RECTIFICATION\n", IndicePoints, IndicePoints, IndicePoints);
 				BoolErr = TRUE;
 				break;
 			}
@@ -625,7 +629,8 @@ void SplitSpectre_search_blank_pass (void)
 	if (FALSE == BoolErr) {
 		for (IndicePoints = 0; VarSplit.Selecteur [ IndicePoints ] . Nmr != -1; IndicePoints ++) {
 			if (SplitSelector_get_diff_sec (VarSplit.Selecteur [ IndicePoints ] . PercentBegin, VarSplit.Selecteur [ IndicePoints ] . PercentEnd) <= 5) {
-				g_print ("ERREUR Temps < a 5 secondes entre BEGIN %d et END %d  -->  RECTIFICATION\n", IndicePoints, IndicePoints);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("ERREUR Temps < a 5 secondes entre BEGIN %d et END %d  -->  RECTIFICATION\n", IndicePoints, IndicePoints);
 				BoolErr = TRUE;
 				break;
 			}
@@ -649,16 +654,18 @@ void SplitSpectre_search_blank_pass (void)
 	}
 	
 	// PRINT CONSOLE
-	for (IndicePoints = 0; VarSplit.Selecteur [ IndicePoints ] . Nmr != -1; IndicePoints ++) {
-		g_print ("[ %2d ]   BEGIN = %5d  END = %5d  PERCENTBEGIN = %f  PERCENTEND = %f\n",
-			VarSplit.Selecteur [ IndicePoints ] . Nmr,
-			(gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint,
-			(gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint,
-			VarSplit.Selecteur [ IndicePoints ] . PercentBegin,
-			VarSplit.Selecteur [ IndicePoints ] . PercentEnd
-			);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		for (IndicePoints = 0; VarSplit.Selecteur [ IndicePoints ] . Nmr != -1; IndicePoints ++) {
+			g_print ("[ %2d ]   BEGIN = %5d  END = %5d  PERCENTBEGIN = %f  PERCENTEND = %f\n",
+				VarSplit.Selecteur [ IndicePoints ] . Nmr,
+				(gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint,
+				(gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint,
+				VarSplit.Selecteur [ IndicePoints ] . PercentBegin,
+				VarSplit.Selecteur [ IndicePoints ] . PercentEnd
+				);
+		}
+		g_print ("\n");
 	}
-	g_print ("\n");
 }
 // LECTURE FICHIER
 //
@@ -677,7 +684,8 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	TYPE_FILE_IS	TypeFileIs = FILE_IS_NONE;
 
 	PRINT_FUNC_LF();
-	g_print("\t%s\n\n", PathNameFile);
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print("\t%s\n\n", PathNameFile);
 	
 	VarSplit.MaxPointsInTab = 0;
 	VarSplit.TypeFileIs = FILE_IS_NONE;
@@ -695,7 +703,8 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	
 	if (FALSE == tagswav_read_file (PathNameFile, &son)) {
 		tagswav_close_file (&son);
-		printf ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", PathNameFile);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			printf ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", PathNameFile);
 		return FALSE;
 	}
 	pFile = son.file;
@@ -703,7 +712,8 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	
 	if (pFile == NULL) {
 		PRINT_FUNC_LF();
-		g_print ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", PathNameFile);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", PathNameFile);
 		return FALSE;
 	}
 	VarSplit.nBitsPerSample = son.FMT.BitsPerSample;
@@ -719,9 +729,10 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 		fclose (pFile);
 		
 		PRINT_FUNC_LF();
-		g_print("Seuls ces formats de bitrates : 8 16 24 et 32 sont pris en charge pour la lecture\n"
-			"Format de bitrate [ %d ] non prit en charge\n", 
-			son.FMT.BitsPerSample);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print("Seuls ces formats de bitrates : 8 16 24 et 32 sont pris en charge pour la lecture\n"
+				"Format de bitrate [ %d ] non prit en charge\n", 
+				son.FMT.BitsPerSample);
 			
 		// DEL ALLOC MEMORY
 		if (NULL != VarSplit.Tab) {
@@ -813,7 +824,8 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 				break;
 			default :
 				PRINT("Ne doit pas arriver ici  !!!!");
-				g_print ("Ce format n'est pas pris en charge : %d\n", son.FMT.BitsPerSample);
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("Ce format n'est pas pris en charge : %d\n", son.FMT.BitsPerSample);
 				fclose (pFile);
 				return FALSE;
 		}
