@@ -80,11 +80,14 @@ INFO_M4A *tagsm4a_remove_info (INFO_M4A *info)
 */
 INFO_M4A *tagsm4a_get_info (DETAIL *detail)
 {
-	gchar      **Larrbuf = NULL;
-	GString      *gstr = NULL;
-	gint          cpt;
-	gchar        *ptr = NULL;
-	INFO_M4A     *ptrinfo = NULL;
+	gchar		**Larrbuf = NULL;
+	GString		*gstr = NULL;
+	gint		cpt;
+	gchar		*ptr = NULL;
+	INFO_M4A	*ptrinfo = NULL;
+	gint		m;
+	gint		s;
+	gint		sec;
 
 	gstr = GetInfo_faad (detail->namefile);
 	Larrbuf = g_strsplit (gstr->str, "\n", 0);
@@ -99,26 +102,25 @@ INFO_M4A *tagsm4a_get_info (DETAIL *detail)
 
 	for (cpt=0; Larrbuf[cpt]; cpt++) {
 
-		/*LC AAC    181.287 secs, 2 ch, 44100 Hz*/
+		// LC AAC	181.287 secs, 2 ch, 44100 Hz
+		// LC AAC	7169.049 secs, 2 ch, 44100 Hz
 		if ((ptr = strstr (Larrbuf[cpt], "LC AAC"))) {
 
-			/* --> 181.287 secs, 2 ch, 44100 Hz */
+			// --> 181.287 secs, 2 ch, 44100 Hz
+			// --> 7169.049 secs, 2 ch, 44100 Hz
 			ptr = strstr (ptr, " secs,");
 			ptr --;
 			while (*ptr != ' ' && *ptr != '\t') ptr --;
 			ptr ++;
-			ptrinfo->time    = g_strdup_printf ("%02d:%02d", atoi (ptr) / 60, atoi (ptr) % 60);
-			ptrinfo->SecTime = atoi (ptr);
-
-			if (detail != NULL) {
-				// detail->ValuePlay.SecTime = ptrinfo->SecTime;
-			}
-
-			ptrinfo->ValueMark.SecTime    = atoi (ptr);
-			// ptrinfo->ValueMark.ValueMarkA = 0.0;
-			// ptrinfo->ValueMark.ValueMarkB = 100.0;
-			// ptrinfo->ValueMark.Value = 0.0;
 			
+			sec = atoi (ptr);
+			s = sec % 60; sec /= 60;
+			m = sec % 60; sec /= 60;
+			if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
+			else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
+
+			ptrinfo->SecTime = sec;
+
 			/* --> 44100 Hz */
 			ptr = strstr (ptr, " Hz");
 			ptr --;
