@@ -88,8 +88,9 @@ INFO_OGG *tagsogg_get_info (DETAIL *detail)
 	TagLib_Tag   *tag;
 	INFO_OGG     *ptrinfo = NULL;
 	const TagLib_AudioProperties *properties;
-	gint          seconds;
-	gint          minutes;
+	gint		m;
+	gint		s;
+	gint		sec;
 
 	ptrinfo = (INFO_OGG *)g_malloc0 (sizeof (INFO_OGG));
 	if (ptrinfo == NULL) return (NULL);
@@ -116,21 +117,13 @@ INFO_OGG *tagsogg_get_info (DETAIL *detail)
 		ptrinfo->Rate            = g_strdup_printf ("%d", taglib_audioproperties_samplerate (properties));
 		ptrinfo->Nominal_bitrate = g_strdup_printf ("%d", taglib_audioproperties_bitrate (properties));
 
-		ptrinfo->SecTime =  taglib_audioproperties_length(properties);
-
-		if (detail != NULL) {
-			// detail->ValuePlay.SecTime = ptrinfo->SecTime;
-		}
-
-		ptrinfo->ValueMark.SecTime    = taglib_audioproperties_length(properties);
-		// ptrinfo->ValueMark.ValueMarkA = 0.0;
-		// ptrinfo->ValueMark.ValueMarkB = 100.0;
-		// ptrinfo->ValueMark.Value = 0.0;
+		ptrinfo->SecTime =
+		sec = taglib_audioproperties_length(properties);
+		s = sec % 60; sec /= 60;
+		m = sec % 60; sec /= 60;
+		if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
+		else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
 		
-		seconds = taglib_audioproperties_length(properties) % 60;
-		minutes = (taglib_audioproperties_length(properties) - seconds) / 60;
-		/*if (minutes == 0 && seconds == 0) seconds = 1;*/
-		ptrinfo->time            = g_strdup_printf ("%02d:%02d", minutes, seconds);
 		ptrinfo->size            = g_strdup_printf ("%d Ko", (gint)libutils_get_size_file (detail->namefile) / 1024);
 			
 		taglib_tag_free_strings();
