@@ -117,23 +117,22 @@ INFO_WAVPACK *tagswavpack_get_info (DETAIL *detail)
 {
 	INFO_WAVPACK	*ptrinfo = NULL;
 	SHNTAG		*ShnTag = GetInfo_shntool (detail->namefile);
+	gint		m;
+	gint		s;
+	gint		sec;
 
 	ptrinfo = (INFO_WAVPACK *)g_malloc0 (sizeof (INFO_WAVPACK));
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 
-	ptrinfo->SecTime  = ShnTag->SecTime;
-	ptrinfo->time     = g_strdup (ShnTag->time);
 	ptrinfo->size     = g_strdup (ShnTag->size);
-
-	if (detail != NULL) {
-		// detail->ValuePlay.SecTime = ptrinfo->SecTime;
-	}
-	
-	ptrinfo->ValueMark.SecTime    = ptrinfo->SecTime;
-	// ptrinfo->ValueMark.ValueMarkA = 0.0;
-	// ptrinfo->ValueMark.ValueMarkB = 100.0;
-	// ptrinfo->ValueMark.Value = 0.0;
+		
+	ptrinfo->SecTime =
+	sec = ShnTag->SecTime;
+	s = sec % 60; sec /= 60;
+	m = sec % 60; sec /= 60;
+	if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
+	else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
 	
 	ShnTag = GetInfo_free_shntool (ShnTag);
 	
