@@ -193,7 +193,7 @@ TRANS trans[] = {
 { _("<b>HomePage</b>") },
 { _("<b>ManPage</b>  ") },
 { _(" <b>Web cdparanoia</b> ") },
-{ _("<b>%a</b>  -  artiste                                   <b>%b</b>  -  titre de l'album        <b>%c</b>  -  numero de la piste\n<b>%d</b>  -  titre de la chanson                <b>%e</b>  -  annee                     <b>%g</b>  -  genre") },
+{ _("<b>%a</b>  -  artiste                                   <b>%b</b>  -  titre de l'album        <b>%c</b>  -  numero de la piste\n<b>%d</b>  -  titre de la chanson                <b>%e</b>  -  annee                     <b>%g</b>  -  genre\n<b>%na</b> -  <b>n</b>o <b>a</b>ccent                            <b>%Tl</b> -  <b>T</b>etsumaki <b>l</b>ower\n<b>%u</b>  -  remplacement de caracteres: <b>%u(AB=C) %u( =_)</b>") },
 { _(" <b>Dossier de stockage</b> ") },
 { _(" CD  ") },
 { _("ABR / CBR / VBR / VBR-NEW") },
