@@ -257,10 +257,11 @@ void on_image_gpl_xcfa_about_realize (GtkWidget *widget, gpointer user_data)
 {
 	gchar     *LineCommand = NULL;
 
-	LineCommand = libutils_get_pathname_pixmaps ("xcfa/gplv3.png");
-	gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
-	g_free (LineCommand);
-	LineCommand = NULL;
+	if( NULL != (LineCommand = xdg_search_data_xdg( "gplv3.png" ))) {
+		gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
+		g_free (LineCommand);
+		LineCommand = NULL;
+	}
 }
 // 
 // 
@@ -268,10 +269,11 @@ void on_image_about_realize (GtkWidget *widget, gpointer user_data)
 {
 	gchar     *LineCommand = NULL;
 
-	LineCommand = libutils_get_pathname_pixmaps ("xcfa/about.png");
-	gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
-	g_free (LineCommand);
-	LineCommand = NULL;
+	if( NULL != (LineCommand = xdg_search_data_xdg( "about.png" ))) {
+		gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
+		g_free (LineCommand);
+		LineCommand = NULL;
+	}
 }
 // 
 // 
